@@ -25,7 +25,6 @@ don't use pure posix, use either BSD- or GNU-extensions.
 #include <signal.h>
 
 #include <stdio.h>
-#include <ctype.h>
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
@@ -80,23 +79,24 @@ don't use pure posix, use either BSD- or GNU-extensions.
 /* its KPATHSEANEWSTYLE. On Solaris, I've only testet with the above  */
 /* teTeX, ant this was KPATHSEAOLDSTYLE.                              */ 
 /*                                                                    */ 
+
 /*#define KPATHSEA*/
 #ifdef KPATHSEA
 #define KPATHMODE NULL    /* put f.e. "cx" here, to consist on cx fonts */
 #define KPATHMAKE 1       /* put 0 here, to disable running   MakeTeXPK */
 #define KPATHDEFF "cmr10" /* fallback font                              */
-/*#define KPATHSEANEWSTYLE *//* be prepared to meet this                */ 
-#define KPATHSEAOLDSTYLE /* old=fine for my teTeX 0.4                   */
+/*#define KPATHSEANEWSTYLE   /* never met this                          */ 
+#define KPATHSEAOLDWSTYLE /* old=fine for my teTeX                      */
 #endif
 
 
 
-/* for eps-figures by calling ghostscript */
+/* experimental support for eps-figures by calling ghostscript */
 #define LETSTRYGS  
-/* disable gs as startup-default. user may enable rendering by command <o>*/
+/* disable gs as startup-default. user may enable rendering by typing (3)<o>*/
 /*#define GSDEFOFF  */
 
-/*#define GSBIN "/usr/local/bin/gs" *//* absolute path of binary */
+/*#define GSBIN "/usr/local/bin/gs"  /* absolute path of binary */
 #define GSBIN "gs"     /* name of binary, use $PATH to locate it */
 
 /* extra pixel to avoid clipping .. */
@@ -104,9 +104,9 @@ don't use pure posix, use either BSD- or GNU-extensions.
 #define GSEXTRAPT 3   /* plus 3 1/72 in epsfile */
 
 /* greyscaling for eps-files */
-/*#define GSGREY 1  *//* 1x1 pxl <> turned off */
-/*#define GSGREY 2  *//* 2x2 pxl <> cheap      */
-#define GSGREY 4      /* 4x4 pxl <> expensive  */
+/*#define GSGREY 1    /* 1x1 pxl <> turned off */
+#define GSGREY 2      /* 2x2 pxl <> cheap      */
+/*#define GSGREY 4    /* 4x4 pxl <> expensive  */
 
 /* bufferlength for reading from gs */
 #define GSBLOCKLEN 8192L 
@@ -126,13 +126,11 @@ don't use pure posix, use either BSD- or GNU-extensions.
 #define GSCODEINTRO  " /SDict 200 dict def SDict begin /showpage { } def "
 #define GSCODESCALE  " %.5f %.5f scale "
 #define GSCODETRANS  " %.2f %.2f translate "
-#define GSCODEROTATE " %.2f rotate " 
+#define GSCODEROTATE " %.2f rotate " /* check this !!!*/
 #define GSCODEFILE   " (%s) run "
 #define GSCODEQUIT   " end showpage quit "
 
 
-/* a little support for color specials  */
-#define LETSTRYCOLOR 
 
 
 /*
@@ -142,12 +140,6 @@ don't use pure posix, use either BSD- or GNU-extensions.
 */
 
 
-/* be careful with storge types !!! */
-#define BMLONG32           /* for architectures where "long int" has 32bits, e.g. i386  */
-/* #define BMLONG64      *//* for architectures where "long int" has 64bits, e.g. alpha */
-/* #define GREYINBMU     *//* waste memory. may be a bit faster    */
-#define COLORS_PER_GREY 16 /* 2^BITS_PER_GREY, no MECK-like things in lX  */
-
 /* if DOSFILES is defined, a dosfilesystem is expected, */ 
 /* incl. ugly naming conventions, like drive-letters and "\" instead ob "/". */
 /* Dont use this with unix sytems */ 
@@ -160,6 +152,12 @@ don't use pure posix, use either BSD- or GNU-extensions.
 /* waiting for IO available: dont do polling */
 #define VGAHASWAITIO
 
+/* please dont touch storge types !!! */
+#define BMLONG                  
+/* #define GREYINBMU   */    /* waste memory. may be a bit faster    */
+#define COLORS_PER_GREY 16   /* 2^BITS_PER_GREY, no MECK-like things in lX  */
+
+
 #define HASMOUSE          /* do this to have a little mousesoupport */
 #define HASWINDOWS        /* X is a window system (tmview not!)*/
 
@@ -220,10 +218,7 @@ now there will be some colorstuff. colors are changable here: with care!
 #define HREFCOL           (COLORS_PER_GREY)+6  
 #define MIXEDCOL          (COLORS_PER_GREY)+7   /* light grey */   
 
-#define TEXTFCOL          (COLORS_PER_GREY)+8   /* text foreground */   
-#define TEXTBCOL          (COLORS_PER_GREY)+9   /* text background */   
-
-#define NUMBER_OF_COLORS  (COLORS_PER_GREY)+10   /*number of colors */
+#define NUMBER_OF_COLORS  (COLORS_PER_GREY)+8   /*number of colors */
 
 
 /* definition of some rgb triples, 16-bit-per-componente   */
@@ -231,7 +226,6 @@ now there will be some colorstuff. colors are changable here: with care!
 /* to make green more blue, edit here.                     */
 /* if you have a grey-scale-only display, set  dark colors */
 /* to dark grey and light colors to light grey.            */
-/* Note: Textcolors are fetched from resources.            */ 
 
 #define PALWHITE 65535,65535,65535   /* white */
 #define PALLGREY 56448,56448,56448   /* light grey */
@@ -244,14 +238,6 @@ now there will be some colorstuff. colors are changable here: with care!
 #define PALLBLUE 44118,51328,65535   /* light blue */
 
 
-/* If we cannot allocate the colors we want, we should fall back   */
-/* to cheap black and white style. This usually happens if we have */
-/* a pseudocolor display and e.g. netscape has stolen all the      */
-/* colortable. The below gives the margin within tmview will accept*/
-/* slightly detuned colors befor falling back to black and white.  */
-#define COLORMARGIN 0.1  /* float between 0. and 1. */
-
-
 /*
 ***************************************************************************
   include general topics
