@@ -4,6 +4,11 @@
 /* distributed without any restrictions.                                 */
 
 
+/*
+   This file is modified for use with Solaris. However, it shoud go
+   with any XWindow ...
+*/
+
 #include "../src/defs.h"
              
 #include <X11/Xos.h>                      /* X header files              */ 
@@ -13,35 +18,50 @@
 #include <X11/cursorfont.h>
 
 
+
+
+
 /* prefered Image format */
-/* you may set up tmview for the depth of your display. 8bit, 16bit and 24bit is  */
-/* tested. Be aware of non-i386 architectures, where a "long int" might not       */
-/* consist of 4 bytes; e.g. alpha uses 8 bytes. The 8bit version based on "uchar" */
-/* should be pretty save ... until they introduce unicode? However, if you use    */
-/* tmview with a depth not the same as defined here, it will become a bit slow.   */
+/* you may set up tmview for the depth of your display. 8bit and 16bit is  */
+/* tested. If you use tmview with a depth not the same as defined here, it */
+/* will become very slow. */
 
 /* 32/24 bit per pixel */
 /*#define IUNIT unsigned long 
 #define IBYTES_PER_PIXEL 4
-#define IBITS_PER_PIXEL 32 */
+#define IBITS_PER_PIXEL 32
+#define IGET_PIXEL(ptr) (*(ptr))
+#define ISET_PIXEL(ptr,c) (*(ptr) = (c))*/ 
 /* 16 bit per pixel */
 /*#define IUNIT unsigned short 
 #define IBYTES_PER_PIXEL 2
-#define IBITS_PER_PIXEL 16 */
+#define IBITS_PER_PIXEL 16
+#define IGET_PIXEL(ptr) (*(ptr))
+#define ISET_PIXEL(ptr,c) (*(ptr) = (c)) */
 /* 8 bit per pixel */
 #define IUNIT unsigned char 
 #define IBYTES_PER_PIXEL 1
-#define IBITS_PER_PIXEL 8 
-
+#define IBITS_PER_PIXEL 8
 #define IGET_PIXEL(ptr) (*(ptr))
-#define ISET_PIXEL(ptr,c) (*(ptr) = (c))
+#define ISET_PIXEL(ptr,c) (*(ptr) = (c)) 
 
 
-/*#define DEBUGX *//* watch tmview contacting the XServer */
+/* #define DEBUGX  /* watch tmview contacting the XServer */
+
+/* from the file globals.c we need ... */
+extern int truevgaxdim,truevgaydim; 
+extern int vgaxdim, vgaydim, directscreen;
+extern int vgastatuslen, vgastatushight, vgamaxstatuslines, vgastatuslines;
 
 #include "writelx.h"
 
                             
+/* from the file subs.c w need ... */
+extern void pfprot(char*, ...);
+extern void pfverb(char*, ...);
+extern void allocmem(void*,long int);
+extern void freemem(void*);
+
 
 typedef unsigned long Pixel;
 
@@ -60,10 +80,9 @@ static char* tforename;
 static char* dwhitename;
 static char* dblackname;
 static char* geometry;
-static int   geox,geoy,geow,geoh,geodx,geody,geof=0;
 
 /* globals belongimg to ma paintings */
-static Pixel palette[NUMBER_OF_COLORS]; 
+static Pixel palette[NUMBER_OF_COLORS];
 static XImage *offimage=NULL;
 static char* offscreen=NULL;
 static int ibytes_per_line, ibytes_per_pixel;
@@ -77,8 +96,8 @@ void (*vgasetclip)(int, int, int, int)=NULL;
 void (*vgadrawrect)(int x, int y, int w, int h, int c)=NULL; 
 void (*vgadrawrector)(int x, int y, int w, int h, int c)=NULL; 
 void (*vgadrawrectbg)(int x, int y, int w, int h, int c)=NULL; 
-void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src, int c)=NULL;
-void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src, int c)=NULL;
+void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src)=NULL;
+void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src)=NULL;
 
 
 /* Function prototypes textdarwing */
@@ -130,12 +149,11 @@ void alloc_off(void) {
   
   if(ibytes_per_pixel != IBYTES_PER_PIXEL) {
     pfprot("\n
-warning: display: found %d-bit depth while optimized for %d-bit.
-  Recompile for better performance.\n", offimage->depth, IBYTES_PER_PIXEL*8);
+warning: display: tmVIEW prefers %d-bit depth. 
+  Recompile for better performance.\n\n", IBYTES_PER_PIXEL*8);
     setvar();
   } else {
-    pfverb("writelx: using built in  %d-bit pixmap functions on a %d-bit display\n",
-      IBYTES_PER_PIXEL*8,offimage->depth);
+    /*pfprot("\nwritelx: using own pix-map functions");*/
     setfix();
   }
 
@@ -156,7 +174,7 @@ warning: display: found %d-bit depth while optimized for %d-bit.
   } else
     pfprot("bits MSBFirst ");
   pfprot("bytes_per_line %d truevgaxdim %d ",ibytes_per_line,truevgaxdim);
-  printf("image at %p, data at %p\n",offimage,offscreen);
+  printf("image at 0x%x, data at 0x%x\n",offimage,offscreen);
 #endif
 }
 
@@ -164,8 +182,7 @@ warning: display: found %d-bit depth while optimized for %d-bit.
 
 void vgaclose(void) {
   free_off();
-  /* tidy up ... is to be done ... colormap? */
-  /* XFreeColors(dpy,colormap,palette,NUMBER_OF_COLORS,0); */
+  /* tidy up ... is to be done */
   XCloseDisplay (dpy);
 }
 
@@ -228,9 +245,8 @@ void mysetclipoff(void) {
 }
 
 
-float setcolormapcol(int i,unsigned int r,unsigned int g,unsigned int b){
+void setcolormapcol(int i,unsigned int r,unsigned int g,unsigned int b){
   XColor color;
-  float fail;
   color.red=r;   
   color.green=g;
   color.blue=b;
@@ -238,154 +254,104 @@ float setcolormapcol(int i,unsigned int r,unsigned int g,unsigned int b){
   color.pixel=i;
   XAllocColor(dpy,colormap,&color);
   XQueryColor(dpy,colormap,&color);
-  fail= (abs(color.red-r) + 
-         abs(color.green-g) +
-         abs(color.blue-b))/3./65535.;
 #ifdef DEBUGX
-  pfprot("set %3d fail %4.2f color: r %5d g %5d b %5d pixel 0x%lx \n", 
-      i,fail,color.red,color.green, color.blue,color.pixel); 
+  pfprot("set %d color: r %d g %d b %d pixel 0x%lx \n", 
+      i,color.red,color.green, color.blue,color.pixel); 
 #endif
   palette[i]=color.pixel;
-  return(fail);
 }
 
 
 void setcolormap(void) {
   int i;
-  float gl,fail1, fail2, colerr;
-  XColor whitecolor, blackcolor, tforecolor, tbackcolor, colorsc, colorex; 
-  char* colorname;
+  float gl;
+  XColor whitecolor, blackcolor, color; 
 
   colormap=DefaultColormap(dpy,screen);
   /* printf("colormap is 0x%x \n",(int) colormap); */
-  colerr=0;
 
-  /* set rgb values of my personal view of black, white and greylevels */
-  XLookupColor(dpy,colormap,dblackname,&blackcolor,&colorsc);
-  XLookupColor(dpy,colormap,dwhitename,&whitecolor,&colorsc);
-  fail1=setcolormapcol(0,whitecolor.red,whitecolor.green,whitecolor.blue);
-  fail2=setcolormapcol(COLORS_PER_GREY-1,blackcolor.red,blackcolor.green,blackcolor.blue);
-  if(MAX(fail1,fail2)>COLORMARGIN){
-    colerr++;
-    XLookupColor(dpy,colormap,"black",&blackcolor,&colorsc);
-    XLookupColor(dpy,colormap,"white",&whitecolor,&colorsc);
-    fail1=setcolormapcol(0,whitecolor.red,whitecolor.green,whitecolor.blue);
-    fail2=setcolormapcol(COLORS_PER_GREY-1,blackcolor.red,blackcolor.green,blackcolor.blue);
-    if(MAX(fail1,fail2)>COLORMARGIN)
-      colerr++;
-  }
-  white =palette[0];
-  black =palette[COLORS_PER_GREY-1];           
-
-  /* non-transparent stuff defaults to black */
-  if(setcolormapcol(COLORS_PER_GREY,PALDRED)>COLORMARGIN){
-    palette[COLORS_PER_GREY]=black;
-    colerr++;
-  }
-  if(setcolormapcol(COLORS_PER_GREY+1,PALDGREEN)>COLORMARGIN){
-    palette[COLORS_PER_GREY+1]=black;
-    colerr++;
-  }
-  if(setcolormapcol(COLORS_PER_GREY+2,PALDBLUE)>COLORMARGIN){
-    palette[COLORS_PER_GREY+2]=black;
-    colerr++;
-  }
-  dred=palette[COLORS_PER_GREY];           
-  dgreen=palette[COLORS_PER_GREY+1];           
-  dblue=palette[COLORS_PER_GREY+2];           
-
-
-  /* transparent stuff I dont care */
+  setcolormapcol(COLORS_PER_GREY,PALDRED);
+  setcolormapcol(COLORS_PER_GREY+1,PALDGREEN);
+  setcolormapcol(COLORS_PER_GREY+2,PALDBLUE);
   setcolormapcol(COLORS_PER_GREY+3,PALLGREY);
   setcolormapcol(COLORS_PER_GREY+4,PALLRED);
   setcolormapcol(COLORS_PER_GREY+5,PALLGREEN);
   setcolormapcol(COLORS_PER_GREY+6,PALLBLUE);
   setcolormapcol(COLORS_PER_GREY+7,PALLGREY);
+  
+  if(dblackname!=NULL) 
+    XAllocNamedColor(dpy,colormap,dblackname,&blackcolor,&color);
+  else {     
+    blackcolor.red   =0;
+    blackcolor.green =0;
+    blackcolor.blue  =0;
+  } 
+  if(dwhitename!=NULL)
+    XAllocNamedColor(dpy,colormap,dwhitename,&whitecolor,&color);
+   else {     
+    whitecolor.red   =65535;
+    whitecolor.green =65535;
+    whitecolor.blue  =65535;
+  }
+
+  for(i=0; i<COLORS_PER_GREY; i++) {
+    gl= (i==0) ? 0.0: exp(GAMMA*log(i/(float) (COLORS_PER_GREY-1)));
+    color.red  =MAX(0,MIN(65535,(1-gl)*blackcolor.red  + gl*whitecolor.red));
+    color.green=MAX(0,MIN(65535,(1-gl)*blackcolor.green+ gl*whitecolor.green));
+    color.blue =MAX(0,MIN(65535,(1-gl)*blackcolor.blue + gl*whitecolor.blue));
+    setcolormapcol(COLORS_PER_GREY-1-i,color.red,color.green,color.blue);
+  }
+
+  white =palette[0];
+  black =palette[COLORS_PER_GREY-1];           
+  dred  =palette[COLORS_PER_GREY];           
+  dgreen=palette[COLORS_PER_GREY+1];           
+  dblue =palette[COLORS_PER_GREY+2];           
   lred  =palette[COLORS_PER_GREY+4];           
   lgreen=palette[COLORS_PER_GREY+5];           
   lblue =palette[COLORS_PER_GREY+6];           
   lgrey =palette[COLORS_PER_GREY+7];           
-
-
-  /* try my very best on the greylevels */
-  for(i=1; i<COLORS_PER_GREY-1; i++) {
-    gl= exp(GAMMA*log(i/(float) (COLORS_PER_GREY-1)));
-    colorex.red  =MAX(0,MIN(65535,(1-gl)*blackcolor.red  + gl*whitecolor.red));
-    colorex.green=MAX(0,MIN(65535,(1-gl)*blackcolor.green+ gl*whitecolor.green));
-    colorex.blue =MAX(0,MIN(65535,(1-gl)*blackcolor.blue + gl*whitecolor.blue));
-    if(setcolormapcol(COLORS_PER_GREY-1-i,colorex.red,colorex.green,colorex.blue)>COLORMARGIN){
-      if(gl<0.3) { colorname="black";
-      } else {
-      if(gl<0.6) { colorname="grey25";
-      } else {
-      if(gl<0.9) { colorname="grey50";
-      } else {     colorname="grey75";
-      }}}
-      XLookupColor(dpy,colormap,colorname,&colorex,&colorsc);
-      if(setcolormapcol(COLORS_PER_GREY-1-i,colorex.red,colorex.green,colorex.blue)>COLORMARGIN)
-        palette[i]=black;
-      colerr++;
-    }
-  }
-
-  XLookupColor(dpy,colormap,tforename,&tforecolor,&colorsc);
-  XLookupColor(dpy,colormap,tbackname,&tbackcolor,&colorsc);
-  fail1=setcolormapcol(TEXTFCOL,tforecolor.red,tforecolor.green,tforecolor.blue);
-  fail2=setcolormapcol(TEXTBCOL,tbackcolor.red,tbackcolor.green,tbackcolor.blue);
-  if(MAX(fail1,fail2)>COLORMARGIN){
-    colerr=1;
-    palette[TEXTFCOL]=black;
-    palette[TEXTBCOL]=white;
-  }
-  if(colerr)
-    pfprot("warning: display: cannot allocate tmview's colors.\n");
 }
 
 
-/* inverse of palette array: hm. this should be done better somehow */
-int invpalette(Pixel cpix){
-  int i;
-  if(cpix==white) return(WHITECOL);
-  if(cpix==black) return(BLACKCOL);
-  for(i=WHITECOL+1; i<NUMBER_OF_COLORS; i++)
-    if(palette[i]==cpix) return(i);
-  pfprot("(invpalette: unknown color)");
-  return(0);
-}
 
-
-void set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom){
-  int geom_result;
+set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom)
+{
+    int geom_result;
     
-  /* set the size hints, algorithm from xlib xbiff */
+    /* set the size hints, algorithm from xlib xbiff */
 
-  hintp->width = hintp->min_width = VGAXDIMMIN;
-  hintp->height = hintp->min_height = VGAYDIMMIN;
-  hintp->flags = PMinSize;
-  hintp->x = hintp->y = 0;
-  geom_result = NoValue;
-  if(geom != NULL) {
-    geom_result = XParseGeometry (geom, &hintp->x, &hintp->y,
+    hintp->width = hintp->min_width = VGAXDIMMIN;
+    hintp->height = hintp->min_height = VGAYDIMMIN;
+    hintp->flags = PMinSize;
+    hintp->x = hintp->y = 0;
+    geom_result = NoValue;
+    if (geom != NULL) {
+        geom_result = XParseGeometry (geom, &hintp->x, &hintp->y,
 				      (unsigned int *)&hintp->width,
 				      (unsigned int *)&hintp->height);
-    if((geom_result & WidthValue) && (geom_result & HeightValue)) {
-      hintp->width = MAX(hintp->width, hintp->min_width);
-      hintp->height = MAX(hintp->height, hintp->min_height);
-      hintp->flags |= USSize;
+	if ((geom_result & WidthValue) && (geom_result & HeightValue)) {
+	    hintp->width = MAX(hintp->width, hintp->min_width);
+	    hintp->height = MAX(hintp->height, hintp->min_height);
+	    hintp->flags |= USSize;
+	}
+	if ((geom_result & XValue) && (geom_result & YValue)) {
+	    hintp->flags += USPosition;
+	}
     }
-    if((geom_result & XValue) && (geom_result & YValue)) {
-      hintp->flags += USPosition;
+    if (!(hintp->flags & USSize)) {
+	hintp->width = w;
+	hintp->height= h;
+	hintp->flags |= PSize;
+    }
+    if (geom_result & XNegative) {
+	hintp->x = DisplayWidth (dpy, DefaultScreen (dpy)) + hintp->x -
+		    hintp->width;
+    }
+    if (geom_result & YNegative) {
+	hintp->y = DisplayHeight (dpy, DefaultScreen (dpy)) + hintp->y -
+		    hintp->height;
     }
-  }
-  if(!(hintp->flags & USSize)) {
-    hintp->width = w;
-    hintp->height= h;
-    hintp->flags |= PSize;
-  }
-  if(geom_result & XNegative) 
-    hintp->x = DisplayWidth(dpy,DefaultScreen(dpy))+hintp->x-hintp->width;
-  if(geom_result & YNegative) 
-    hintp->y = DisplayHeight(dpy,DefaultScreen(dpy))+hintp->y-hintp->height;
 }
 
 
@@ -393,18 +359,21 @@ void set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom){
 
 void vgaopen(void) {
   char* displayname=NULL;
-#ifdef DEBUGX
-  XPixmapFormatValues* pixforlist;
   int* depthlist;
+  int n;
+  XPixmapFormatValues* pixforlist;
   XVisualInfo* vislist;
   XVisualInfo  vistemp;
-  int npixforlist,i,n;
-
-  pfprot("(vgaopen ...\n"); 
-#endif
+  int npixforlist;
+  int i;
 
   offscreen=NULL;  /* to be shure */
 
+  
+#ifdef DEBUGX
+  pfprot("(vgaopen ...\n",XResourceManagerString(dpy)); 
+#endif
+
   /* better ask option !! */    
   dpy=XOpenDisplay(displayname);
   if (!dpy) {
@@ -441,11 +410,15 @@ void vgaopen(void) {
     dblackname="black";
 
   dwhitename=XGetDefault(dpy,"","DviLX.background");
-  /*if(dwhitename==NULL)
-    dwhitename=XGetDefault(dpy,"OpenWindows","DataBackground");*/
+  if(dwhitename==NULL)
+    dwhitename=XGetDefault(dpy,"OpenWindows","DataBackground");
   if(dwhitename==NULL)
     dwhitename="OldLace";
 
+  geometry=XGetDefault(dpy,"DviLX","geometry");
+  /*  if(geometry==NULL)
+    geometry="500x500"; */
+
   
 
 #ifdef DEBUGX
@@ -510,6 +483,7 @@ void vgagraph(void) {
 
   XSetWindowAttributes attr;
   XWindowAttributes gattr;
+  char* geom=NULL; 
   XSizeHints hints;
   XGCValues values;
   unsigned long valuemask, attrmask;
@@ -519,13 +493,9 @@ void vgagraph(void) {
   pfprot("(vgagraph ... \n)");
 #endif	 
     
-  /* now that geometry: too many sources? */  
-  geometry=XGetDefault(dpy,"DviLX","geometry"); /* A. from resources */
-  if(cmlgeometry!=NULL)
-    stralloccpy(&geometry,cmlgeometry);         /* B. -geometry option */
-  vgaxdim = MAX(VGAXDIMMIN,vgaxdim);            /* C. -d option */
+  vgaxdim = MAX(VGAXDIMMIN,vgaxdim);  
   vgaydim = MAX(VGAYDIMMIN,vgaydim);
-  set_sizehints(&hints, vgaxdim, vgaydim, 10,10,geometry); /* merge them all */
+  set_sizehints (&hints, vgaxdim, vgaydim, 10,10,geometry);
  
 
   /* setup window attributes */
@@ -537,7 +507,7 @@ void vgagraph(void) {
    
 
   attr.background_pixel = palette[0];
-  attr.backing_store=WhenMapped;
+  attr.backing_store=NotUseful;
   attrmask = CWBackPixel | CWEventMask | CWBackingStore;
   dviwin = XCreateWindow (dpy, RootWindow(dpy, screen), hints.x, hints.y,
 			   hints.width, hints.height,5, 
@@ -559,7 +529,7 @@ void vgagraph(void) {
 
   vgaxdim=gattr.width;
   vgaydim=gattr.height;
-  truevgaxdim=((vgaxdim-1) | 3) +1;
+  truevgaxdim=(vgaxdim | 3) +1;
   truevgaydim=vgaydim;
 
   values.function=GXcopy;
@@ -593,13 +563,7 @@ void vgagraph(void) {
 /***************************************************************************/
 
 
-/* dimm colors for color special */
-int mydimm(int color, int dimm) {
-  return(color>>dimm);
-}
-
-
-void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
+void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -608,7 +572,6 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
   BMUNIT premask, firstpremask;
   register BMUNIT data, mask;
   short sbmu_wide;
-  Pixel blackc;
 
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
@@ -626,9 +589,8 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
-  premask = ((BMUNIT)1) << (BITS_PER_BMUNIT-1);
+  premask = 1 << (BITS_PER_BMUNIT-1);
   firstpremask = premask >> skip;
-  blackc=palette[(BLACKCOL)>>c];
 
   supj=supj+tx-minj;
   supi=supi+ty-mini;
@@ -639,7 +601,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
     sbmu=srow;
     data=*sbmu;
     for (j = tx;j<supj;j++) {       
-      if(data & mask) XPutPixel(offimage,j,i,blackc);
+      if(data & mask) XPutPixel(offimage,j,i,black);
       mask >>= 1;
       if(!mask) {
         mask=premask;
@@ -658,7 +620,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
 
 
 
-void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) { 
+void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -669,7 +631,6 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) {
   register BMUNIT data, mask;
   short sbmu_wide;
   int rs, firstrs;
-  uchar paintc, sourcec;
 
   /* fprintf(prot,"(vgacopybitmap8 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh);                             
@@ -685,12 +646,11 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) {
      return;
   }
 
-    
-  paintc=0;
+  
   sbmu_wide= ROUNDUP(sw << GREYSCALE_LOG2,BITS_PER_BMUNIT);
   skip= minj & ((BITS_PER_BMUNIT>>GREYSCALE_LOG2)-1);
   sx= minj >> (BITS_LOG2-GREYSCALE_LOG2);
-  premask = ((((BMUNIT)1)<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
+  premask = ((1<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
   firstpremask = premask >> (skip<< GREYSCALE_LOG2);
   firstrs = BITS_PER_BMUNIT-GREYSCALE - skip*GREYSCALE;
 
@@ -704,20 +664,8 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) {
     sbmu=srow;
     data=*sbmu;
     for (j = tx;j<supj;j++) {
-#ifndef LETSTRYCOLOR      
-      if((paintc=((data & mask) >> (rs+c))))
-        if(XGetPixel(offimage,j,i)==white)
-          XPutPixel(offimage,j,i,palette[paintc]);
-#else
-      if((paintc=((data & mask) >> (rs+c)))){
-        if((sourcec=invpalette(XGetPixel(offimage,j,i)))){
-          if((paintc+=sourcec & (COLORS_PER_GREY-1))>COLORS_PER_GREY-1) 
-             paintc=COLORS_PER_GREY-1;
-          paintc|=sourcec & ~(COLORS_PER_GREY-1);
-	}
-        XPutPixel(offimage,j,i,palette[paintc]);
-      }
-#endif
+      if(XGetPixel(offimage,j,i)==white) 
+         XPutPixel(offimage,j,i,palette[((data & mask) >> rs)]);
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       if(!mask) {
@@ -772,7 +720,6 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   int i,j,supj,supi;
   Pixel cpix;
-  uchar sourcec, paintc;
 
   /* fprintf(prot,"(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -780,8 +727,8 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
   if(tx+w>ofscx2+1) w=ofscx2+1-tx;
-  if(w <= 0 || h<= 0 || c==0) {
-     /*fprintf(prot,"clipped all away or white: no drawings)\n"); */
+  if(w <= 0 || h<= 0) {
+     /*fprintf(prot,"clipped all away. no drawings)\n"); */
      return;
   }
  /* fprintf(prot,"clipped or box: tx %d ty %d w %d h %d   \n",
@@ -795,19 +742,8 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   for (i=ty;i<supi;i++) 
     for (j=tx;j<supj;j++) 
-#ifndef LETSTRYCOLOR      
-      if(XGetPixel(offimage,j,i)==white)
-        XPutPixel(offimage,j,i,cpix);
-#else
-      if((sourcec=invpalette(XGetPixel(offimage,j,i)))){
-        if((paintc=c+(sourcec & (COLORS_PER_GREY-1)))>COLORS_PER_GREY-1) 
-           paintc=COLORS_PER_GREY-1;
-        paintc|=sourcec & ~(COLORS_PER_GREY-1);
-        XPutPixel(offimage,j,i,palette[paintc]);
-      } else {
-        XPutPixel(offimage,j,i,cpix);
-      }
-#endif
+      if(XGetPixel(offimage,j,i)==white) 
+         XPutPixel(offimage,j,i,cpix);
   if(directscreen) {
     XPutImage(dpy,dviwin,imagecopygc,offimage,tx,ty,tx,ty,w,h); 
   /* XFlush(dpy); */ 
@@ -854,7 +790,7 @@ void myfillboxbg(int tx, int ty, int w, int h, int c) {
 }
 
 
-void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
+void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -864,7 +800,6 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
   register BMUNIT data, mask;
   short sbmu_wide;
   IUNIT *ydest, *xdest;
-  Pixel blackc;
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -883,11 +818,10 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
   /* fprintf(prot,"clipped: tx %d ty %d mi %d si %d mj %d sj %d \n",
      tx,ty,mini,supi,minj,supj); */
 
-  blackc=palette[(BLACKCOL)>>c];
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
-  premask = ((BMUNIT)1) << (BITS_PER_BMUNIT-1);
+  premask = 1 << (BITS_PER_BMUNIT-1);
   firstpremask = premask >> skip;
 
   ydest=((IUNIT*)(offscreen+ty*ibytes_per_line))+tx;  
@@ -898,7 +832,7 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
     sbmu=srow;
     data=*sbmu;
     for (j = minj;j<supj;j++) {       
-      if(data & mask) ISET_PIXEL(xdest,blackc);
+      if(data & mask) ISET_PIXEL(xdest,black);
       mask >>= 1;
       xdest++;
       if(!mask) {
@@ -919,7 +853,7 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
 
 
 
-void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src, int c) { 
+void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -931,7 +865,6 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src, int c) {
   short sbmu_wide;
   int rs, firstrs, w,h;
   IUNIT *ydest, *xdest;
-  uchar paintc, sourcec;
 
   /*printf("(vgacopybitmap8 : src 0x%x tx %d ty %d sw %d sh %d, ...\n",
        src,tx,ty,sw, sh);                             
@@ -956,10 +889,9 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src, int c) {
   sbmu_wide= ROUNDUP(sw << GREYSCALE_LOG2,BITS_PER_BMUNIT);
   skip= minj & ((BITS_PER_BMUNIT>>GREYSCALE_LOG2)-1);
   sx= minj >> (BITS_LOG2-GREYSCALE_LOG2);
-  premask = ((((BMUNIT)1)<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
+  premask = ((1<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
   firstpremask = premask >> (skip<< GREYSCALE_LOG2);
   firstrs = BITS_PER_BMUNIT-GREYSCALE - skip*GREYSCALE;
-  sourcec=0;
 
   ydest=((IUNIT*)(offscreen+ty*ibytes_per_line))+tx;
   srow=((BMUNIT*)src)+mini*sbmu_wide+sx;
@@ -970,21 +902,8 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src, int c) {
     sbmu=srow;
     data=*sbmu;
     for (j = minj;j<supj;j++) {
-#ifndef LETSTRYCOLOR       
-      if((paintc=((data & mask) >> (rs+c)))) 
-        if(IGET_PIXEL(xdest)==white)
-          ISET_PIXEL(xdest,palette[paintc]);
-#else
-      if((paintc=((data & mask) >> (rs+c)))){ 
-        if(IGET_PIXEL(xdest)!=white){
-          sourcec=invpalette(IGET_PIXEL(xdest));
-          if((paintc+=sourcec & (COLORS_PER_GREY-1))>COLORS_PER_GREY-1) 
-             paintc=COLORS_PER_GREY-1;
-          paintc|=sourcec & ~(COLORS_PER_GREY-1);
-   	}
-        ISET_PIXEL(xdest,palette[paintc]);
-      }
-#endif
+      if(IGET_PIXEL(xdest)==white) 
+         ISET_PIXEL(xdest,palette[((data & mask) >> rs)]);
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       xdest++;
@@ -1047,7 +966,6 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   IUNIT *ydest, *xdest;
   int i,j;
   Pixel cpix;
-  uchar sourcec, paintc;
 
   /* fprintf(prot,"(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -1055,8 +973,8 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
   if(tx+w>ofscx2+1) w=ofscx2+1-tx;
-  if(w <= 0 || h<= 0 || c==0) {
-     /*fprintf(prot,"clipped all away or white: no drawings)\n"); */
+  if(w <= 0 || h<= 0) {
+     /*fprintf(prot,"clipped all away. no drawings)\n"); */
      return;
   }
 
@@ -1068,21 +986,8 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   for (i=h;i>0;i--) {
     xdest=ydest; 
     for (j=w;j>0;j--) {
-
-#ifndef LETSTRYCOLOR      
-      if(IGET_PIXEL(xdest)==white) 
-         ISET_PIXEL(xdest,cpix);
-#else
-      if((sourcec=invpalette(IGET_PIXEL(xdest)))){
-        if((paintc=c+(sourcec & (COLORS_PER_GREY-1)))>COLORS_PER_GREY-1) 
-           paintc=COLORS_PER_GREY-1;
-        paintc|=sourcec & ~(COLORS_PER_GREY-1);
-        ISET_PIXEL(xdest,palette[paintc]);
-      } else {
-        ISET_PIXEL(xdest,cpix);
-      }
-#endif
-      xdest++;
+       if(IGET_PIXEL(xdest)==white) ISET_PIXEL(xdest,cpix);
+       xdest++;
     }
     ((char*)ydest)+=ibytes_per_line;
   }
@@ -1188,7 +1093,6 @@ void setvar(void) {
   vgadrawrect=myfillbox; 
   vgadrawrector=myfillboxor; 
   vgadrawrectbg=myfillboxbg; 
-  vgadimm=mydimm;
   vgacopybitmapgs=mycopybitsgs;
   vgacopybitmapbw=mycopybitsbw;
 }
@@ -1199,7 +1103,6 @@ void setfix(void) {
   vgadrawrect=myfillboxfix; 
   vgadrawrector=myfillboxorfix; 
   vgadrawrectbg=myfillboxbgfix; 
-  vgadimm=mydimm;
   vgacopybitmapgs=mycopybitsgsfix;
   vgacopybitmapbw=mycopybitsbwfix;
 }
@@ -1302,6 +1205,7 @@ uchar vgagetchar(int mode) {
     mode==2: peek next key, dont block
   */
   uchar res=KEYNOP;  
+  int i;
   XEvent event;
   XEvent dummyevent;
   XKeyEvent *keyev;
@@ -1309,6 +1213,7 @@ uchar vgagetchar(int mode) {
   XMotionEvent *moev;
   XCrossingEvent *crossev;
   XButtonEvent *butev;
+  
   KeySym keysym;
   char *keynam;
   int slen;
@@ -1320,10 +1225,9 @@ uchar vgagetchar(int mode) {
      if(mode!=2) mode2char=-1;
      return(res);
   }
-  
   nev=XEventsQueued(dpy,QueuedAfterFlush);
   if(mode!=1 && nev==0) return(res);
-  XNextEvent(dpy,&event);
+  XNextEvent(dpy,&event); 
   switch (event.type) {
   case KeyPress:
     keyev = (XKeyEvent *) &event;
@@ -1358,34 +1262,12 @@ uchar vgagetchar(int mode) {
     break;
   case ConfigureNotify:
     if(offscreen==NULL) break; /* not started up jet */
+    /* pfprot("(oldsize %d %d)",vgaxdim,truevgaydim); */
     conev=(XConfigureEvent *) &event;
-    /* figure out position of our window. anyone around who knows? */
-    if(conev->send_event==1 && geof==0) {
-      geodx=geox-conev->x;
-      geody=geoy-conev->y;
-      geof=1;
-    }
-    if(conev->send_event==1 || geof==0) {
-      geox=conev->x;
-      geoy=conev->y;
-    }
-    geow=conev->width;
-    geoh=conev->height;
-    /*
-    freemem(&cmlgeometry);
-    allocmem(&cmlgeometry,100); 
-    if(-1== snprintf(cmlgeometry,99,"%dx%d+%d+%d", geow,geoh,geox+geodx,geoy+geody))
-      {pfprot("\nfatal error: gemetry .. writelx ??\n");exit(1);}
-    */
-#ifdef DEBUGX
-    pfprot("(configure notify for %ld flag %d: geometry: %dx%d+%d+%d)\n",
-         conev->window,conev->send_event,geow,geoh,geox+geodx,geoy+geody);
-#endif	 
-    pfprot("(oldsize %d %d)",vgaxdim,truevgaydim);
     newxdim = MAX(VGAXDIMMIN,conev->width);  
     newydim = MAX(VGAYDIMMIN,conev->height);
     if(newxdim==vgaxdim && newydim==truevgaydim) break;
-    truevgaxdim=((newxdim-1) | 3) + 1;
+    truevgaxdim=(newxdim | 3) + 1;
     truevgaydim=newydim;
     vgaxdim=newxdim;
     vgaydim=newydim;
@@ -1438,30 +1320,43 @@ uchar vgagetchar(int mode) {
 /* now the font stuff ...                                                  */
 
 
+Pixel tforepixel;
+Pixel tbackpixel;
 Font  tfontfont;
 XFontStruct* tfontstruct;
 char* offstatus=NULL;
 
 
 void preparefont(void) {
+  XColor colordef, colorex;
   XGCValues values;
   unsigned long valuemask;
   char** fontlist;
-  int nfontlist;
+  int i,nfontlist;
+  
+  if(tforename!=NULL) {
+    XAllocNamedColor(dpy,colormap,tforename,&colordef,&colorex);
+    tforepixel=colordef.pixel;
+  } else 
+    tforepixel= BlackPixel(dpy,screen);     
+  if(tbackname!=NULL) {
+    XAllocNamedColor(dpy,colormap,tbackname,&colordef,&colorex);
+    tbackpixel=colordef.pixel;
+  } else 
+    tbackpixel= WhitePixel(dpy,screen); 
 
+  
   if(tfontname==NULL) tfontname="*-fixed-*";
   fontlist=XListFonts(dpy,tfontname,20,&nfontlist);
 
-#ifdef DEBUGX 
-  { int i; 
-    pfprot("(fontnames:\n");
-    for(i=0;i<nfontlist;i++)
-     pfprot("%s\n",fontlist[i]);
-    pfprot("\n");
-  }
+#ifdef DEBUGX  
+  pfprot("(fontnames:\n");
+  for(i=0;i<nfontlist;i++)
+   pfprot("%s\n",fontlist[i]);
+  pfprot("\n");
+  if(nfontlist==0) vgaerror("no such font");
 #endif  
 
-  if(nfontlist==0) vgaerror("no such font");
   tfontstruct=XLoadQueryFont(dpy,fontlist[0]);
   if(tfontstruct==NULL) vgaerror("Cant load font");
   
@@ -1489,12 +1384,12 @@ void preparefont(void) {
 
   tfontfont=tfontstruct->fid;
  
-  values.foreground=palette[TEXTFCOL];
-  values.background=palette[TEXTBCOL];
+  values.foreground=tforepixel;
+  values.background=tbackpixel;
   values.font=tfontfont;
   valuemask= GCForeground | GCBackground | GCFont ;
   wintextgc=XCreateGC(dpy, dviwin, valuemask, &values);
-  values.foreground=palette[TEXTBCOL];
+  values.foreground=tbackpixel;
   valuemask= GCForeground; 
   wincleartextgc=XCreateGC(dpy, dviwin, valuemask, &values);
 
