@@ -22,9 +22,6 @@
 void vgaopen(void);
 void vgagraph(void);
 void vgaclose(void);
-void vgagetmouse(int*, int*,int*, int*);
-void vgasetmouse(int, int);
-int vgawaitio(fd_set*, fd_set*, struct timeval*);
 unsigned char vgagetchar(int);
 int  vgacharfdesc(void);
 void (*vgasetclip)(int, int, int, int);
@@ -32,12 +29,9 @@ void (*vgaupdate)(int, int, int, int);
 void (*vgadrawrect)(int, int, int, int, int);
 void (*vgadrawrector)(int, int, int, int, int);
 void (*vgadrawrectbg)(int, int, int, int, int);
-int  (*vgadimm)(int, int);
-void (*vgacopybitmapgs)(int, int, int, int, void*, int);
-void (*vgacopybitmapbw)(int, int, int, int, void*, int);
+void (*vgacopybitmapgs)(int, int, int, int, void*);
+void (*vgacopybitmapbw)(int, int, int, int, void*);
 void vgascreen(int);
-void vgaxscroll(short);
-void vgayscroll(short);
 void vgadrawstatus(char, int, int);
 void vgaupdatestatus(void);
 int  vgasetstatuslines(int);
