@@ -42,6 +42,7 @@ void rolldownbookmk(bookmarklist* bookmks) {
 
 int findrolldownbookmk(bookmarklist* bookmks,int name) {
   int i;
+  bookmark *bbu;
   if(bookmks==NULL) return(0);
   for(i=0;i<bookmks->n;i++) if(bookmks->d[i]->name == name) break;
   if(i>=bookmks->n) return(0);
@@ -194,24 +195,15 @@ void filemkskill(void) {
 }
 
 void rolldownfilemk(void) {
-  int i, maxloop;
-  char *bustr=NULL;
-  filemark *bbu;
+  int i;
+  filemark* bbu;
 #ifdef DEBUGBMK
   pfprot("(rolldownfile... )");
 #endif
   if(nfilemks<=0) return;
-  maxloop=nfilemks; /* put a -1 here if deleting stuff ? */
-  while(maxloop>0) {
-    maxloop--;
-    bbu=filemks[0];
-    for(i=0;i<nfilemks-1;i++) filemks[i]=filemks[i+1];
-    filemks[i]=bbu;
-    if(dvistandard(&bustr,filemks[0]->lastpos.dvifilename)) 
-      break; /* loop nominal ends here */
-    /* freefilemknumber(0); ... no, we dont delete these things! */   
-  };
-  freemem(&bustr);
+  bbu=filemks[0];
+  for(i=0;i<nfilemks-1;i++) filemks[i]=filemks[i+1];
+  filemks[i]=bbu;
   curfmk=filemks[0];
   curbmks=&(curfmk->bookmks);
 }
@@ -232,6 +224,7 @@ void rollupfilemk(void) {
 
 int findrolldownfilemk(char* fname) {
   int i;
+  filemark *bbu;
 #ifdef DEBUGBMK
   pfprot("(findfile. %s in %d.. )",fname,nfilemks);
 #endif
@@ -275,7 +268,8 @@ void freefilemk(void) {
 }
 
 void freefilemkname(char* fname) {
-  int i;
+  int i,j;
+  filemark *bbu;
 #ifdef DEBUGBMK
   pfprot("(freefilename... )");
 #endif
@@ -303,6 +297,7 @@ void allocnewfilemk(char* name) {
            (MMTOPXL(curfmk->papxmm)-vgaxdim)/2-MMTOPXL(curfmk->hoffmm);
   curfmk->lastpos.dviypos= -INSIDEPXL - MMTOPXL(curfmk->voffmm);
   curfmk->lastpos.fshrink= fshrink;
+
   curbmks=&(curfmk->bookmks);
   bookmksinit(curbmks);
 #ifdef DEBUGBMK
@@ -312,6 +307,7 @@ void allocnewfilemk(char* name) {
 } 
 
 void updatefilemk(void) {
+  int i;
   if(visfmk==NULL) return;
 #ifdef DEBUGBMK
   pfprot("(updatefile. ");
