@@ -7,7 +7,7 @@
 #include "defs.h"
 #include "drawit.h"
 
-/*#define DEBUGDRAW */
+/* #define DEBUGDRAW */
 
 
 /* eieiei and again forward decl. */
@@ -16,40 +16,50 @@ void drawpage(int, int, int, int, int);
 /* ugly switch */
 static int tmpnomarks=0;
 
-/* all drawlist drawings refer to ... */
-static pagelistelement* thedrawpage;
-static int thexpos, theypos;
-
   
-#define DRAWLISTSTEP 500  /* allocate blocks of 500 drawlistelements */
 
-void drawlistinit(pagelistelement* dpage) {
-  thedrawpage=dpage;
-  freelrumem(&(thedrawpage->drawlist));
-  thedrawpage->ndraws=0;
-  thedrawpage->maxdraws=0;
+void drawlistclear(void) {
+  int i=0;
+  drawlistelement *cptr, *nptr; 
+  cptr=thedrawlist;
+  while(cptr != NULL){
+    nptr=cptr->next;
+    i++;
+    freemem(&cptr);
+    cptr=nptr;
+  }
+  thedrawlist=NULL;
+#ifdef DEBUGDRAW
+  if(i!=0)
+    pfprot("(drawlistclear: freed %d entries, thats %.1fKbyte)",
+          i,i*sizeof(drawlistelement) / 1024.0);
+  else
+   pfprot("(drawlistclear 0)"); 
+#endif
 }
 
-void drawlistfix(void) {
-  thedrawpage->maxdraws=MAX(1,thedrawpage->ndraws);  
-  realloclrumem(&(thedrawpage->drawlist),
-    thedrawpage->maxdraws*sizeof(drawlistelement));
-  unlocklrumem(&(thedrawpage->drawlist)); 
-}
-
-
 drawlistdata* drawlistadd(selfdrawfunction* sdf) {
-  drawlistelement* dleptr;
-  if(thedrawpage->maxdraws==thedrawpage->ndraws) {
-    thedrawpage->maxdraws+=DRAWLISTSTEP;  
-    realloclrumem(&(thedrawpage->drawlist),
-      thedrawpage->maxdraws*sizeof(drawlistelement));
-     locklrumem(&(thedrawpage->drawlist)); 
+  int i;
+  drawlistelement* nptr; 
+  allocmem(&nptr,sizeof(drawlistelement));
+  nptr->next=NULL;
+  nptr->drawmyself=sdf;
+  if(thedrawlist==NULL) {
+    thedrawlist=nptr;
+    nptr->prev=nptr;
+  } else {
+    thedrawlist->prev->next=nptr;
+    nptr->prev=thedrawlist->prev;
+    thedrawlist->prev=nptr;
   }
-  dleptr=thedrawpage->drawlist+thedrawpage->ndraws;
-  thedrawpage->ndraws++;
-  dleptr->drawmyself=sdf;
-  return(&(dleptr->data));
+  return(&(nptr->data));
+  /* i=0;
+  nptr=thedrawlist;
+  while(nptr != NULL){
+    nptr=nptr->next;
+    i++;
+  }
+  pfprot(" %d elements now)\n",i); */ 
 }
 
 
@@ -114,7 +124,9 @@ void drawupdatepage(void) {  /* this does a total reset */
 }
 
 
+ 
 void drawhidemark(int x, int y) {
+   int ms=MARKSIZE;
    tmpnomarks=1;
 #if CURSORSNOTONSCREEN  /* switch drirect screen off */
    vgascreen(0);
@@ -125,8 +137,8 @@ void drawhidemark(int x, int y) {
 void drawshowmark(int x, int y, int col){
    int ms=MARKSIZE; 
    /* (*vgasetclip)(0,0,vgaxdim-1,vgaydim-1); */
-   (*vgadrawrect)(x-ms,y,2*ms+1,1,vgadimm(BLACKCOL,0));
-   (*vgadrawrect)(x,y-ms,1,2*ms+1,vgadimm(BLACKCOL,0));
+   (*vgadrawrect)(x-ms,y,2*ms+1,1,BLACKCOL);
+   (*vgadrawrect)(x,y-ms,1,2*ms+1,BLACKCOL);
    (*vgadrawrectbg)(x-ms,y-ms,2*ms+1,2*ms+1,col);
    drawaddupdatelist(x-ms,y-ms,x+ms,y+ms);
 }
@@ -241,17 +253,6 @@ void drawshowrect(void){
 }
 
 
-void drawhideallmarksandrect(void){  
-  if(!recton){
-    drawhideallmarks();
-    return;
-  }
-  drawhiderect();
-  recton=0;
-  drawhideallmarks();
-  recton=1;
-}
-
 
 void drawcharbmp(drawlistdata* arg) { 
   chdesc *thechar;
@@ -261,12 +262,11 @@ void drawcharbmp(drawlistdata* arg) {
   thechar=(*arg).chr.chdp;  
   if(thechar->bmp.bits == NULL) pkloadchar(thechar);
   else touchlrumem(&(thechar->bmp.bits));
- (*vgacopybitmapbw)( (*arg).chr.h -thexpos -thechar->hof,
-                     (*arg).chr.v -theypos -thechar->vof, 
+ (*vgacopybitmapbw)( (*arg).chr.h -dvixpos -thechar->hof,
+                     (*arg).chr.v -dviypos -thechar->vof, 
                      thechar->bmp.w,
                      thechar->bmp.h,
-                     thechar->bmp.bits,
-                     (*arg).chr.c);
+                     thechar->bmp.bits);
 }
 
 void drawcharbmp2bw(drawlistdata* arg) {  
@@ -280,12 +280,11 @@ void drawcharbmp2bw(drawlistdata* arg) {
     if(thechar->bmp.bits == NULL) pkloadchar(thechar);
     pkshrinkcharazbw(thechar);
   } else touchlrumem(&(thechar->bmp2.bits));
-  (*vgacopybitmapbw)((*arg).chr.h -thexpos -thechar->hof2,
-                     (*arg).chr.v -theypos -thechar->vof2, 
+  (*vgacopybitmapbw)((*arg).chr.h -dvixpos -thechar->hof2,
+                     (*arg).chr.v -dviypos -thechar->vof2, 
                      thechar->bmp2.w,
                      thechar->bmp2.h,
-                     thechar->bmp2.bits,
-                     (*arg).chr.c);
+                     thechar->bmp2.bits);
 }
 
 void drawgscript(drawlistdata* arg){
@@ -303,21 +302,19 @@ void drawgscript(drawlistdata* arg){
   } 
   if(gse->suspect==B_OK && gse->bmp.w== gse->bmp2.w) { 
     touchlrumem(&(gse->bmp.bits));
-    (*vgacopybitmapbw)((*arg).gscript.h -thexpos,
-                       (*arg).gscript.v -theypos, 
+    (*vgacopybitmapbw)((*arg).gscript.h -dvixpos,
+                       (*arg).gscript.v -dviypos, 
                        gse->bmp.w,
                        gse->bmp.h,
-                       gse->bmp.bits,
-                       0); /* do not dimm gscript */
+                       gse->bmp.bits);
   }
   if(gse->suspect==B_OK && gse->bmp.w!= gse->bmp2.w) { 
     touchlrumem(&(gse->bmp2.bits));
-    (*vgacopybitmapgs)((*arg).gscript.h -thexpos,
-                       (*arg).gscript.v -theypos, 
+    (*vgacopybitmapgs)((*arg).gscript.h -dvixpos,
+                       (*arg).gscript.v -dviypos, 
                        gse->bmp2.w,
                        gse->bmp2.h,
-                       gse->bmp2.bits,
-                       0); /* do not dimm gscript */
+                       gse->bmp2.bits);
   }
   /*printf("<!!!Drawgscript DONE :-)\n"); */
 }
@@ -326,7 +323,7 @@ void drawgscript(drawlistdata* arg){
 void drawcharbmp2gs(drawlistdata* arg) {  
   chdesc *thechar;
 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("(CharBmp2GS ");
 #endif
  
@@ -336,16 +333,15 @@ void drawcharbmp2gs(drawlistdata* arg) {
     if(thechar->bmp.bits == NULL) pkloadchar(thechar);
     pkshrinkcharazprecgs(thechar);
   } else touchlrumem(&(thechar->bmp2.bits));
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot(" call vgacopybitmapgs ");
 #endif
-  (*vgacopybitmapgs)((*arg).chr.h -thexpos -thechar->hof2,
-                     (*arg).chr.v -theypos -thechar->vof2, 
+  (*vgacopybitmapgs)((*arg).chr.h -dvixpos -thechar->hof2,
+                     (*arg).chr.v -dviypos -thechar->vof2, 
                      thechar->bmp2.w,
                      thechar->bmp2.h,
-                     thechar->bmp2.bits,
-                     (*arg).chr.c);
-#ifdef DEBUGDRAW        
+                     thechar->bmp2.bits);
+#ifdef DEBUGDRAW	
   pfprot(" done)");
 #endif
 }
@@ -353,16 +349,16 @@ void drawcharbmp2gs(drawlistdata* arg) {
 
 
 void drawruleor(drawlistdata* arg) {
-  (*vgadrawrector)( (*arg).rect.x-thexpos, 
-                    (*arg).rect.y-theypos, 
+  (*vgadrawrector)( (*arg).rect.x-dvixpos, 
+                    (*arg).rect.y-dviypos, 
                     (*arg).rect.w, 
                     (*arg).rect.h, 
                     (*arg).rect.c);
 } 
 
 void drawrulebg(drawlistdata* arg) {
-  (*vgadrawrectbg)( (*arg).rect.x-thexpos, 
-                    (*arg).rect.y-theypos, 
+  (*vgadrawrectbg)( (*arg).rect.x-dvixpos, 
+                    (*arg).rect.y-dviypos, 
                     (*arg).rect.w, 
                     (*arg).rect.h, 
                     (*arg).rect.c);
@@ -373,148 +369,124 @@ void drawrulebg(drawlistdata* arg) {
 drawpage() is split up into faststuff, slowstuff, finalstuff.
 */
 
-int drawpagefaststuff(pagelistelement* apage, int x1, int y1, int x2, int y2) {
+int drawpagefaststuff(int x1, int y1, int x2, int y2) {
   drawlistelement *eptr;
-  long i, didskipslowstuff;
+  int i, didskipslowstuff;
 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("(drawpagefaststuff ...");
 #endif
-  if(apage==NULL) return(0);
-  readpage(apage);
-  if(apage->drawlist==NULL) return(0);
-  thedrawpage=apage;
-  thexpos=dvixpos-thedrawpage->xoffset;
-  theypos=dviypos-thedrawpage->yoffset;
-  locklrumem(&(thedrawpage->drawlist)); 
-  eptr=thedrawpage->drawlist;
-  for(i=0; i<thedrawpage->ndraws; i++, eptr++) {
+  eptr=thedrawlist;
+  while(eptr != NULL) {
     if(eptr->drawmyself!=drawgscript)
       eptr->drawmyself(&(eptr->data));
+    eptr=eptr->next;
   }
   didskipslowstuff=0;
-  eptr=thedrawpage->drawlist;
-  for(i=0; i<thedrawpage->ndraws; i++, eptr++) {
+  eptr=thedrawlist;
+  while(eptr != NULL) {
     if(eptr->drawmyself==drawgscript){
       if(eptr->data.gscript.gse->suspect==B_OK)
         eptr->drawmyself(&(eptr->data)); 
       else 
         didskipslowstuff=1;
     }
+    eptr=eptr->next;
   }
-  unlocklrumem(&(thedrawpage->drawlist)); 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("drawpagefaststuff: done)");
 #endif
   return(didskipslowstuff);
 }
 
 
-void drawpagefinalstuff(pagelistelement *apage,int x1,int y1,int x2,int y2){
+void drawpagefinalstuff(int x1, int y1, int x2, int y2) {
   HTeX_Anchor *HTeXAp;
   int i;
 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("(drawpagefinalstuff ...");
 #endif
-  if(apage==NULL) return;
-  thedrawpage=apage;
-  thexpos=dvixpos-thedrawpage->xoffset;
-  theypos=dviypos-thedrawpage->yoffset;
   /* boarder = paper farme */
-  (*vgadrawrect)(-thexpos-MMTOPXL(visfmk->hoffmm)-1,
-                 -theypos-MMTOPXL(visfmk->voffmm)-1,
+  (*vgadrawrect)(-dvixpos-MMTOPXL(visfmk->hoffmm)-1,
+                 -dviypos-MMTOPXL(visfmk->voffmm)-1,
                   MMTOPXL(visfmk->papxmm)+3,1,BORDERCOL);
-  (*vgadrawrect)(-thexpos-MMTOPXL(visfmk->hoffmm)-1,
-                 -theypos-MMTOPXL(visfmk->voffmm)-1,
+  (*vgadrawrect)(-dvixpos-MMTOPXL(visfmk->hoffmm)-1,
+                 -dviypos-MMTOPXL(visfmk->voffmm)-1,
                   1,MMTOPXL(visfmk->papymm)+3,BORDERCOL);
-  (*vgadrawrect)(-thexpos-MMTOPXL(visfmk->hoffmm)-1,
-                 -theypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->papymm)+1,
+  (*vgadrawrect)(-dvixpos-MMTOPXL(visfmk->hoffmm)-1,
+                 -dviypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->papymm)+1,
                   MMTOPXL(visfmk->papxmm)+3,1,BORDERCOL);
-  (*vgadrawrect)(-thexpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->papxmm)+1,
-                 -theypos-MMTOPXL(visfmk->voffmm)-1,
+  (*vgadrawrect)(-dvixpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->papxmm)+1,
+                 -dviypos-MMTOPXL(visfmk->voffmm)-1,
                   1,MMTOPXL(visfmk->papymm)+3,BORDERCOL);
   if(frameon){
     /* draw  frame */
     (*vgadrawrect)(
-    -thexpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
-    -theypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
+    -dvixpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
+    -dviypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
     MMTOPXL(visfmk->papxmm-visfmk->rrandmm)-
     MMTOPXL(visfmk->lrandmm)+3,1,FRAMECOL);
     (*vgadrawrect)(
-    -thexpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
-    -theypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->papymm-visfmk->urandmm)+1,
+    -dvixpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
+    -dviypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->papymm-visfmk->urandmm)+1,
     MMTOPXL(visfmk->papxmm-visfmk->rrandmm)-
     MMTOPXL(visfmk->lrandmm)+3,1,FRAMECOL);
     (*vgadrawrect)(
-    -thexpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
-    -theypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
+    -dvixpos-MMTOPXL(visfmk->hoffmm)+MMTOPXL(visfmk->lrandmm)-1,
+    -dviypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
     1,MMTOPXL(visfmk->papymm-visfmk->urandmm)-
     MMTOPXL(visfmk->orandmm)+3,FRAMECOL);
     (*vgadrawrect)(
-    -thexpos-MMTOPXL(visfmk->hoffmm)+
+    -dvixpos-MMTOPXL(visfmk->hoffmm)+
     MMTOPXL(visfmk->papxmm-visfmk->rrandmm)+1,
-    -theypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
+    -dviypos-MMTOPXL(visfmk->voffmm)+MMTOPXL(visfmk->orandmm)-1,
     1,MMTOPXL(visfmk->papymm-visfmk->urandmm)-
     MMTOPXL(visfmk->orandmm)+3,FRAMECOL);
   }
-  /*if(apage==cpage) */
   drawshowrect();
   /* fprintf(prot,"(read tmp %d)",tmpnomarks); */
   if(hypon) {
-    HTeXAp = apage->anchorlist;
-    for (i=0; i < apage->nanchors; i++, HTeXAp++) {
+    HTeXAp = cpage->anchorlist;
+    for (i=0; i < cpage->nanchors; i++, HTeXAp++) {
       if ((HTeXAp->type&HTeX_A_HREF) == 0) continue; /* Only box hrefs */
-        vgadrawrectbg(HTeXAp->x1pxl-thexpos,HTeXAp->y1pxl-theypos, 
+        vgadrawrectbg(HTeXAp->x1pxl-dvixpos,HTeXAp->y1pxl-dviypos, 
       HTeXAp->x2pxl-HTeXAp->x1pxl+1,HTeXAp->y2pxl-HTeXAp->y1pxl+1,HREFCOL);
     }
   }
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("drawpagefinalstuff: done)");
 #endif
 }
 
 int speedx1, speedx2, speedy1, speedy2;
 
-int speedupslowstuff(pagelistelement* apage,int x1, int y1, int x2, int y2) {
+int speedupslowstuff(int x1, int y1, int x2, int y2) {
   drawlistelement *eptr;
   int didsomeslowstuff;
-  long i;
 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("(speedupslowstuff ...");
 #endif
-  if(apage==NULL) {
-#ifdef DEBUGDRAW        
-    pfprot("apege=null)");
-#endif
-    return(B_SUSPECT);
-  }
-  readpage(apage);
-  if(apage->drawlist==NULL) return(B_SUSPECT);
-  thedrawpage=apage;
-  thexpos=dvixpos-thedrawpage->xoffset;
-  theypos=dviypos-thedrawpage->yoffset;
-  locklrumem(&(thedrawpage->drawlist)); 
   didsomeslowstuff=B_SUSPECT;
-  eptr=thedrawpage->drawlist;
-  for(i=0; i<thedrawpage->ndraws &&  didsomeslowstuff==B_SUSPECT; i++, eptr++) {
+  eptr=thedrawlist;
+  while((eptr != NULL) && (didsomeslowstuff==B_SUSPECT)) {
     if(eptr->drawmyself==drawgscript){
       if(   eptr->data.gscript.gse->suspect==B_SUSPECT
          || eptr->data.gscript.gse->suspect==B_SKIPONCE){
        gsloadbmp(eptr->data.gscript.gse);
        didsomeslowstuff=eptr->data.gscript.gse->suspect;
        if(eptr->data.gscript.gse->suspect==B_OK) {
-          speedx1=eptr->data.gscript.h -thexpos,
-          speedy1=eptr->data.gscript.v -theypos,
-          speedx2=eptr->data.gscript.h -thexpos +eptr->data.gscript.gse->bmp2.w -1,
-          speedy2=eptr->data.gscript.v -theypos +eptr->data.gscript.gse->bmp2.h -1;
+          speedx1=eptr->data.gscript.h -dvixpos,
+          speedy1=eptr->data.gscript.v -dviypos,
+          speedx2=eptr->data.gscript.h -dvixpos +eptr->data.gscript.gse->bmp2.w -1,
+          speedy2=eptr->data.gscript.v -dviypos +eptr->data.gscript.gse->bmp2.h -1;
         }
       }
     }
+    eptr=eptr->next;
   }
-  unlocklrumem(&(thedrawpage->drawlist)); 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("speedupslowstuff: done)");
 #endif
   return(didsomeslowstuff);
@@ -522,10 +494,9 @@ int speedupslowstuff(pagelistelement* apage,int x1, int y1, int x2, int y2) {
 
 
 void drawpage(int x1, int y1, int x2, int y2, int speedup) {
-  int dssscp=0;
-  int dssspp=0;
+  int dsss;
 
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot("(drawpage: dest: %d %d %d %d dvipos %d %d ...",
               x1,y1,x2,y2,dvixpos,dviypos);
 #endif
@@ -539,48 +510,35 @@ void drawpage(int x1, int y1, int x2, int y2, int speedup) {
   /*Farbtest  ... */
   /*for(i=0;i<64;i++)
     (*vgadrawrect)(i*10,0,10,10,i);*/  
-  dssspp=drawpagefaststuff(ppage,x1,y1,x2,y2);
-  dssscp=drawpagefaststuff(cpage,x1,y1,x2,y2);
-  if(!speedup || (!dssscp && !dssspp)) {
-    drawpagefinalstuff(ppage,x1,y1,x2,y2);
-    drawpagefinalstuff(cpage,x1,y1,x2,y2);
-    if(tmpnomarks==0) drawshowallmarks();
-    drawaddupdatelist(x1,y1,x2,y2);
-  } else {
-    /* did skip slow stuff and want to catch up */
-    drawpagefinalstuff(ppage,x1,y1,x2,y2);
-    drawpagefinalstuff(cpage,x1,y1,x2,y2);
+  dsss=drawpagefaststuff(x1,y1,x2,y2);
+  if(dsss && speedup) {
+    /* did skip slow stuff ... */
+    drawpagefinalstuff(x1,y1,x2,y2);
     if(tmpnomarks==0) drawshowallmarks();
     drawaddupdatelist(x1,y1,x2,y2);
     updateall(); /* use "all" here. care! */   
     /* try to do the slow stuff: */
-    while(speedupslowstuff(cpage,x1,y1,x2,y2)==B_OK) {
+    while(speedupslowstuff(x1,y1,x2,y2)==B_OK) {
       /* some slow stuff is fast now: do the whole page again  */
       (*vgasetclip)(speedx1,speedy1,speedx2,speedy2);
       (*vgadrawrect)(0,0,vgaxdim,vgaydim,WHITECOL);
-      drawpagefaststuff(cpage,0,0,vgaxdim-1,vgaydim-1);
-      drawpagefinalstuff(cpage,0,0,vgaxdim-1,vgaydim-1);
-      if(tmpnomarks==0) drawshowallmarks();
-      drawaddupdatelist(speedx1,speedy1,speedx2,speedy2);
-      updatelist();   
-    }
-    while(speedupslowstuff(ppage,x1,y1,x2,y2)==B_OK) {
-      /* some slow stuff is fast now: do the whole page again  */
-      (*vgasetclip)(speedx1,speedy1,speedx2,speedy2);
-      (*vgadrawrect)(0,0,vgaxdim,vgaydim,WHITECOL);
-      drawpagefaststuff(ppage,0,0,vgaxdim-1,vgaydim-1);
-      drawpagefinalstuff(ppage,0,0,vgaxdim-1,vgaydim-1);
+      drawpagefaststuff(0,0,vgaxdim-1,vgaydim-1);
+      drawpagefinalstuff(0,0,vgaxdim-1,vgaydim-1);
       if(tmpnomarks==0) drawshowallmarks();
       drawaddupdatelist(speedx1,speedy1,speedx2,speedy2);
       updatelist();   
     }
     if(tmpnomarks==0) drawshowallmarks();
-  }
+  } else {
+    drawpagefinalstuff(x1,y1,x2,y2);
+    if(tmpnomarks==0) drawshowallmarks();
+    drawaddupdatelist(x1,y1,x2,y2);
+  }    
   (*vgasetclip)(0,0,vgaxdim-1,vgaydim-1);
   if(statusforce==1) drawstatusline();
   if(statusforce==2) statusforce=1; /* Hack: keep once */
   tmpnomarks=0;
-#ifdef DEBUGDRAW        
+#ifdef DEBUGDRAW	
   pfprot(" ... drawpage done)");
 #endif
 }
@@ -625,7 +583,7 @@ void setcounterstr(void) {
    i=MAX(0,i);
    counterstr[0]=0;
    for(j=0;j<=i;j++) {
-     sprintf(bustr,"%ld;",MIN(9999,MAX(-9999,cpage->count[j])));
+     sprintf(bustr,"%d;",MIN(9999,MAX(-9999,cpage->count[j])));
      strcat(counterstr,bustr);
    }
    counterstr[strlen(counterstr)-1]=0;
@@ -639,7 +597,7 @@ int doupdate=1;
 void drawstatusmarks(void) {
   char bustr1[180], bustr2[180];
   char* refstr;
-  int ol;
+  int bui,ol;
 
   if(cpage==NULL || visfmk==NULL) return;
   if(statusforce) {
@@ -650,10 +608,7 @@ void drawstatusmarks(void) {
   case 0:
     refstr=NULL;
     if(hypon) 
-      if(!htex_withinanchor(cpage,dvixpos+marksxpxl, dviypos+marksypxl, &refstr))
-        if(ppage!=NULL)
-          htex_withinanchor(ppage,marksxpxl+dvixpos-ppage->xoffset, 
-                              marksypxl+dviypos-ppage->yoffset, &refstr);
+      htex_withinanchor(cpage,dvixpos+marksxpxl, dviypos+marksypxl, &refstr);
     if(refstr==NULL) {
       sprintf(bustr1,"(%%.%df,%%.%df) [%s]",unitcomma,unitcomma,unitname);
       sprintf(bustr2, bustr1, 
