@@ -4,8 +4,7 @@
 /* distributed without any restrictions.                                 */
 
 drawlistdata* drawlistadd(selfdrawfunction* sdf);
-void drawlistinit(pagelistelement*);
-void drawlistfix(void);
+void drawlistclear(void);
 void updateall(void);
 void updatelist(void);
 void drawpage(int,int,int,int,int);
@@ -14,7 +13,6 @@ void drawshowallmarks(void);
 void drawshowfixedmarksonly(void);     
 void drawhideallmarks(void); 
 void drawhidefixedmarksonly(void);
-void drawhideallmarksandrect(void);
 void drawshowrect(void); 
 void drawhiderect(void); 
      
