@@ -15,9 +15,20 @@ by xdvi.
 
 #include "defs.h"
 
-/*#define DEBUGEPS  *//* debug eps-file reading, rendering etc. */
-/*#define DEBUGEPSS *//* parsing of special arguments */
+/*#define DEBUGEPS    /* debug eps-file reading, rendering etc. */
+/*#define DEBUGEPSS /* parsing of special arguments */
 
+/* 
+This file handles some aspects of the PSFile-special.  
+At a first step, the arguments of the special are interpreted in 
+order to draw a bounding box. At a second step, we try to
+call ghostscript to render the eps-file. This is done much less
+sophisticated than it is in xdvi. Still, part of the code comes
+from xdvi.
+*/
+
+/* #define DEBUGEPS      /* general */
+/* #define DEBUGEPSS     /* parsing special */
 
 /**********************************************************/
 /* gscriptlist: array of espfiles within one dvifile      */
@@ -53,27 +64,6 @@ void killgscript(void){
 #endif
 }
 
-int testgse(gslistelement* gse){
-  gslistelement* igse;
-#ifdef DEBUGEPS
-  pfprot("(testgse:");
-#endif
-  igse=gslistfirst;
-  while(igse!=NULL){
-    if(igse==gse)
-      break;
-    igse=igse->nextgse;
-  }  
-  if(igse!=gse || gse==NULL) {
-    pfprot("(testgse: invalid pointer)"); 
-    return(0);
-  }
-#ifdef DEBUGEPS
-  pfprot(")");
-#endif
-  return(1);
-}
-
 gslistelement* allocgscript(char* gsfile, char* argfile, short w, short h, float res, char* code){
 #ifdef DEBUGEPS
   pfprot("(allocgscript %s %d %d %.3f",gsfile, w, h, res);
@@ -110,6 +100,7 @@ gslistelement* allocgscript(char* gsfile, char* argfile, short w, short h, float
 
 
 gslistelement* searchgscript(char* gsfile, short w, short h,float res, char* code){
+  int i;
   gslistelement* gse;
 #ifdef DEBUGEPS
   pfprot("(searchgsciptlist %s %d %d %.3f ",gsfile, w, h, res);
@@ -174,7 +165,7 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
   char gscode3c[GSARGLEN];
   char gscode3e[GSARGLEN];
   char gscode3f[GSARGLEN];
-  char* gscode=NULL;
+  char* gscode;
 
   gslistelement* gse;
   drawlistdata* data;
@@ -223,7 +214,7 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
 #endif
 
 /* PART 2: Get other args ******************************/
-  argllx=arglly=argurx=argury=argangle=argrwi=argrhi=0;
+
   while(*cp != '\0') {
     while(isspace(*cp)) ++cp;
     cp_beg=cp;  
@@ -407,17 +398,16 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
 
 
 /* PART 4: Add gscommand to drawlist  **************************/
-  needmem=0;
   if(doeps==DOEPS){
     needmem=((long)lheight)*((long)ROUNDUP(lwidth,BITS_PER_BMUNIT)) 
        *BYTES_PER_BMUNIT;
-    if(needmem > maxlinmem) { /* try blacknwhit only */
+    if(needmem > MAXLINMEM) { /* try blacknwhit only */
       lheight=height;
       lwidth=width;
     }
     needmem=((long)lheight)*((long)ROUNDUP(lwidth,BITS_PER_BMUNIT)) 
        *BYTES_PER_BMUNIT;
-    if(needmem > maxlinmem){
+    if(needmem > MAXLINMEM){
       pfverb("(epsfile: ignoring <%s>, too large)", specstr);
     } else {
       sprintf(gscode1,GSCODEFILE,lfullfile);
@@ -448,7 +438,7 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
   }
 /* PART 4: Add frame to drawlist  **************************/
 #ifndef DEBUGEPS
-  if(doeps==DONTEPS || needmem > maxlinmem){
+  if(doeps==DONTEPS || needmem > MAXLINMEM){
 #endif
     data=drawlistadd(*drawrulebg);
     (*data).rect.c=TFMCOL;
@@ -501,6 +491,8 @@ FILE* gs_in_write;
 
 
 int startgs(char* epsname, short width, short height, float res, char* gscode) {
+  int returncode;
+  int i;
   char gsargsize[GSARGLEN];
   char gsargres[GSARGLEN];
 
@@ -566,7 +558,7 @@ int waitio(void){
 #ifdef VGAHASWAITIO   /* select cares about keybord */
   timeout.tv_sec = TIMEOUT;
   timeout.tv_usec = 0;
-#else                /* select ignores keybord */
+#else               /* select ignores keybord */
   timeout.tv_sec = 0;
   timeout.tv_usec = 100000L; /* 0.1 sec */
 #endif;
@@ -592,14 +584,18 @@ int readgs(bitmap *bmp2){
   uchar buff[GSBLOCKLEN];
   uchar *sp, *buffend;
   long bufflen;
+  uchar c;
   long  count;
   long expected;
   uchar ukey;
-  short jbit,jbm;
+  short i,jbit,jbm;
   long lshift;
   BMUNIT *dp;
+
   int returncode;
 
+
+  
 /* set GSPIPE_OUT_READ to non-blocking I/O ... | O_NONBLOCK */
 /* set GSPIPE_OUT_READ to generate SIGIO   ... | O_ASYNC */
   fcntl(GSPIPE_OUT_READ, F_SETFL,
@@ -698,14 +694,17 @@ int readgs(bitmap *bmp2){
 
 
 void  gsloadbmp(gslistelement* gse) {
+  int i,j, gsres;
   char mess[MAXPATHSTR];
+  
+  
 #ifdef DEBUGEPS
-  int i,j;
-  pfprot("(gsloadbmp: 0x%x %s %d %d %.2f ...)",
-     gse,gse->gsfile,gse->bmp2.w,gse->bmp2.h, gse->res);
+  pfprot("(gsloadbmp: %s %d %d %.2f ...)",
+     gse->gsfile,gse->bmp2.w,gse->bmp2.h, gse->res);
 #endif
-  if(!testgse(gse)) return;  /* <<< remove this in future version */
+
   if(gse->suspect==B_ESCAPE) return;
+
   /* user message, similar to ingorethis, */
   sprintf(mess,"... RENDERING <%s> (%dx%d)",gse->argfile,gse->bmp.w,gse->bmp.h);
   if(vgastatuslines!=1) drawstatusline();
