@@ -8,29 +8,25 @@
 
 /* real globals used for dvi processing*/
 fontdescvect* fontvect=NULL;
+drawlistelement *thedrawlist=NULL;
 pagelistelement *pagelist=NULL;
 int pageanz;
 gslistelement* gslistfirst=NULL;
 gslistelement*  gslistlast=NULL;
 int dvierrorflag;
 pagelistelement *cpage=NULL;
-pagelistelement *ppage=NULL;
 float fshrink=1.0;
 int ishrinkonly=0;
 uchar colors=BLACKNWHITE;
 uchar doeps=DONTEPS;
-int  dimmthresh=4;
 uchar *greytab=NULL;
 long dvimag;
-uchar dimmcolor;
 
 /* arguments as globals */
 int verbose=0;
-char *cmlgeometry=NULL;
 int numberargstrlen;
 char  *numberargstr=NULL;
 
-
 /* real globals for displaymanaging */
 int vgaxdim, vgaydim;
 int directscreen;
@@ -44,7 +40,6 @@ int textx1pxl, texty1pxl, textx2pxl, texty2pxl;
 int textx3pxl, texty3pxl, textx4pxl, texty4pxl;
 float rectxmm, rectymm, rectwmm, recthmm; 
 char *dviname=NULL;
-uchar ppagemode;
 
 float unitomm,mmtounit;
 int unitcomma;
@@ -52,8 +47,6 @@ char* unitname;
  
 
 /* global constants */
-long   maxlrumem;
-long   maxlinmem;
 BMUNIT	*bit_masks=NULL; 
 uchar *bit_count=NULL;
 char* workdir;
@@ -68,7 +61,6 @@ int savestartup;
 long newmag;
 int xres,yres;
 int pagemovetop, moveoverpages, bookmkmode, unitstar;
-int dispos=0;
 
 
 /* globals for multiple files and bookmarks ... */
