@@ -150,6 +150,7 @@ void htex_beginpage(pagelistelement *page) /* Starting a new page */
 }
 
 void htex_endpage(void) { /* This page has been completed */
+  int i;
   HTeX_Anchor *HTeXAp;
 
   if(HTeXcpage->anchorsdone!=DOING) return;
@@ -269,8 +270,9 @@ void htex_parseanchor(char* cp, HTeX_Anchor *anchor) {
 /* Should use WWW library stuff ? */
 
 void htex_anchor(int beginend, char* cp) {
+  int i;
   int oldllx, oldlly, oldurx, oldury;
-  HTeX_Anchor *HTeXAp=NULL;
+  HTeX_Anchor *HTeXAp, *HTeXAp2;
 
   if (beginend == END) {
     HTeXAnestlevel--;
@@ -371,7 +373,7 @@ void htex_handletag(char* cp)
 /* Only understand my (=Arthur's) version of anchors so far */
 /* ie.: his TYPE=text for hrefs, frag for names */
 
-void hy_handletag(char* cp) {
+hy_handletag(char* cp) {
   int beginend=BEGIN;
   
 
@@ -452,9 +454,11 @@ htex_listpage(pagelistelement* page) {
 int htex_findonpage(char* href, pagelistelement* page) {
   int ia;
   HTeX_Anchor *HTeXAp;
+  char astr[256];
   char *cp;
 	
   if (href == NULL) return(-1); /* shouldn't happen? */
+
 #ifdef DEBUGHYP
   htex_listpage(page);
 #endif
@@ -474,6 +478,7 @@ int htex_findonpage(char* href, pagelistelement* page) {
 
 /* find the anchor on any page done */
 void htex_findondonepage(char* href, int* ip, int* ia) {
+  HTeX_Anchor *HTeXAp;
 
   *ip=-1;
   *ia=-1;
