@@ -1,6 +1,6 @@
 #define HELPWIDTH 60 
 #define HELPSTR "\
-LIST OF COMMANDS WITH TYPICAL ARGUMENTS ************ V 01.03
+LIST OF COMMANDS WITH TYPICAL ARGUMENTS ************ V 99.06
 
      <i>/<m>          goto previous/next page 
 (NUM)<g>              goto page NUM w.r.t. TeX-counters
@@ -14,7 +14,7 @@ LIST OF COMMANDS WITH TYPICAL ARGUMENTS ************ V 01.03
      <w>              move to a bookmark
      <^>              move back
 
-     <o>              display options 
+     <o>              toggle greyscaling and eps-rendering
      <x>              toggle statusline-information
      <t>              set unit of measurement
 
@@ -138,9 +138,9 @@ SELECTING THE PAGE****************************************
 
      <i> moves towards the beginning of the DVIfile, while
      <m> moves towards the end. A single argument (N) may
-     specify the amount of movement in pages. However, (N)
-     will NOT become the default value. The argument is (*), 
-     the page-moving-mode is toggled. See above.  
+     specify the amount of movement in pages. If the
+     argument is (*), the page-moving-mode is toggled. See
+     above.  
 
      Example: 
      (1)<i> selects the previous page <m> selects the next
@@ -154,7 +154,7 @@ SELECTING THE PAGE****************************************
      arguments given, the others will be taken as <*>.
 
      Example: 
-     (26)<g> selects the first page after the current page
+     (26)(i) selects the first page after the current page
      with a value of 26 in \\count0.
 
 
@@ -201,12 +201,9 @@ ZOOMING ****************************************************
  
        This command requires one argument (F) which must be
        between 0.05 and 2.  F will become the zoom-factor
-       and the visible-area will be redrawn. Use (*)<v> to 
-       adjust the zoom-factor such that the page horizontaly 
-       fits the visible-area.
-
-       If the zoom-factor is 1, the pixels found in pk-files 
-       are just copied one by one to the screen. Since the
+       and the visible-area will be redrawn. If the
+       zoom-factor is 1, the pixels found in pk-files are
+       just copied one by one to the screen. Since the
        resolution of our days screens seems to be less than
        that of our days printers, and since you may still
        want to use the same pk-files for printing and
@@ -215,24 +212,33 @@ ZOOMING ****************************************************
        you will set F to something like 0.3, depending on
        the involved resolutions. When the screenmark is
        visible (see <l>) the position of the screenmark is
-       taken as the origin of zooming, i.e. it is fixed. 
-       When the screenmark is not visible, the middle of the 
-       screen is fixed. The current zoom-factor is displayed 
-       in the optional statusline, see <x>.
+       taken as the origin of zooming, i.e. it is
+       fixed. When the screenmark is not visible, the
+       middle of the screen is fixed. The current
+       zoom-factor is displayed in the optional statusline,
+       see <x>.
 
-       There are two zooming modi. The integer modus 
-       requieres 1/f to be an integer. This modus is quite 
-       fast, so good values are F=0.5, 0.333, 0.25, 0.2, 
-       0.167 etc. The good thing about the slow modus is, 
-       that it allows you to choose the zoom-factor 
-       arbitrary (between 0.05 and 2). So poor students with 
-       small screens might find some optimum to make the 
-       text fit and still be readable. The bad thing about 
-       the slow modus is that it is slow.  But since once 
-       zoomed glyphs are kept in memory, this slowness only 
-       hurts the first few pages after changing the
-       zoom-factor. Modus selection is  done by the display 
-       options <o>. 
+       There are two zooming modi. The fast modus works
+       only if 1/F is an integer.  So good values are
+       F=0.5, 0.333, 0.25, 0.2, 0.167 and so on. When in
+       the fast modus, the <+>/<-> keys described below
+       step through that values. And since F is to be small
+       anyway, you may never use <v> to set it explicitly.
+
+       The good thing about the slow modus is, that it
+       allows you to choose the zoom-factor arbitrary
+       (between 0.05 and 2). So poor students with small
+       screens might find some optimum to make the text fit
+       and still be readable. The bad thing about the slow
+       modus is that it is slow.  But since once zoomed
+       glyphs are kept in memory, this slowness only hurts
+       the first few pages after changing the
+       zoom-factor. Anyway, <*><v> brings you back in the
+       fast modus, choosing the nearest possible
+       zoom-factor therefore.
+
+       Sorry. The problem may be solved either by a better
+       zooming algorithm or faster computers.
 
 <+>/<-> Zoom in/out
 
@@ -243,6 +249,14 @@ ZOOMING ****************************************************
        the current zoom-factor. This is likely to result in
        the slow modus.
 
+       Example:
+       (0.17)<v>   set zoomfactor to 0.17               (slow)
+       (10)<+>     set zoomfactor to 1.1*0.17=0.187     (slow)
+       (3)<->      set zoomfactor to 0.97*1.87=0.181    (slow)
+       <->           ...          to 0.97*0.181=0.176   (slow)
+       (*)<v>        ...          to 1/6=0.167          (fast)
+       <+>           ...          to 1/5=0.2            (fast)
+             
 
 BOOKMARKS **************************************************
 
@@ -317,39 +331,33 @@ and manual-bookmarks, while <^> acts on back-bookmarks.
 
 CHOOSING WHAT'S ON THE DISPLAY *****************************
 
-<o> Display options
+<o> Toggle greyscaling and eps-rendering
+ 
+       When the zoom-factor is less than 1, the glyphs may
+       be displayed using grey-levels, making them more
+       smooth. This takes some memory, so you may switch it
+       off. On high-res displays there is no need for it
+       anyway.
 
-       This command collects a number of general options 
-       on how the things get on the screen. Use the cursor
-       keys (or <u>/<n>/<h>/<h>) to navigate.
+       There is limited support for rendering eps-files by
+       running ghostscript. However, this sometimes is quite
+       slow and memory intensive, so you may turn it off.
+       If rendering is enabled the results are buffered.
+       Hence, if the eps-files are updated by some graphics
+       program, you need to do a <*><r> to force rerendering
+       To disable certain eps-files individually, abort the
+       rendering process by <esc>.
 
-       > Greyscales. When the zoom-factor is less than 1, 
-       the glyphs may be displayed using grey-levels, making 
-       them more smooth. This takes some memory, so you are 
-       allowed to switch it off. On high-res displays there 
-       is no need for greyscaling anyway.
 
-       > Eps-rendering. There is limited support for 
-       rendering eps-files by running ghostscript. However, 
-       this sometimes is quite slow and memory intensive, so 
-       you may turn it off. If rendering is enabled the 
-       results are buffered. Hence, if the eps-files are 
-       updated by some graphics program, you need to do a 
-       <*><r> to force rerendering. To disable certain 
-       eps-files individually, abort the rendering process 
-       by <esc>.
+       When a single numeric argument is given, the display 
+       mode is set as indicated below. Whithout arguments,
+       the mode is toggled.
 
-       > Double-page. There is also limited support for 
-       viewing two pages beside each other. Again their
-       is some memory required to keep it all buffered.
-       You may disable double paged viewing entirely. You
-       may let tmview deceide on basis of the zoom-factor.
-       Or you may permanently enable this feature.
-
-       > Zooming. There is a fast zooming mode allowing
-       only zomming by 1/f where f is required to be an
-       integer. And there is an arbitrary mode to be
-       selected.
+       (0)<o>  black and white 
+       (1)<o>  greyscaling
+       (2)<o>  black and white, eps-rendering
+       (3)<o>  greyscaling, eps-rendering
+ 
 
 <x> Toggle statusline-information
 
