@@ -7,7 +7,7 @@
 #include"defs.h"
 
 /*#define DEBUGDVI */
-/*#define DEBUGFONTDATABASE */ 
+/*#define DEBUGFONTDATABASE*/
 /*#define DEBUGMACRO */
 
 
@@ -20,11 +20,11 @@
 #define MAXFONTDATA 10000
 
 static int nfontdatabase;
-static int supfontdatabase;
+static int maxfontdatabase;
 
 void initfontdatabase(void) {
   nfontdatabase=0;
-  supfontdatabase=0;
+  maxfontdatabase=0;
   fontdatabase=NULL;
 #ifdef DEBUGFONTDATABASE
   pfprot("(initfontdatabase)");
@@ -44,19 +44,16 @@ int allocfontdesc(char* ffpath, char* ffname, long dvimag, long scf, long dsz) {
     pfprot(" found unused ");
 #endif
   } else {
-    if(supfontdatabase<=nfontdatabase) {
+    if(maxfontdatabase<=nfontdatabase) {
       if(nfontdatabase> MAXFONTDATA) {
         pfprot("\nfatal error: fontdatabase exploded .. :-(\n");
         exit(1);
       }
 #ifdef DEBUGFONTDATABASE
-      pfprot(" reallocmem fontdatabase %x to ",fontdatabase);
-#endif
-      supfontdatabase+=FONTDATASTEP;
-      reallocmem(&fontdatabase,supfontdatabase * sizeof(fontdesc));
-#ifdef DEBUGFONTDATABASE
-      pfprot("%x ",fontdatabase);
+      pfprot(" allocmem ");
 #endif
+      maxfontdatabase+=FONTDATASTEP;
+      reallocmem(&fontdatabase,maxfontdatabase * sizeof(fontdesc));
     }
     font=fontdatabase+nfontdatabase;
     i=nfontdatabase;
@@ -71,8 +68,6 @@ int allocfontdesc(char* ffpath, char* ffname, long dvimag, long scf, long dsz) {
   font->pkfile = NULL;
   font->vffile = NULL;
   font->encoding = NULL; 
-  font->vffontvect = NULL;
-  font->vffirst=-1;  
   font->mch = -1;
   font->usecount=0;
   stralloccpy(&(font->fonam),ffname);
@@ -88,7 +83,7 @@ int searchfontdatabase(char* ffpath, char* ffname,
   fontdesc* font;
   int i;
 #ifdef DEBUGFONTDATABASE
-  pfprot("(searchfontdatabase %s %s mag %6.1f scf %d dsz %d",ffpath,ffname,dvimag,scf,dsz);
+  pfprot("(searchfontdatabase %s %s %6.1f ",ffpath,ffname,dvimag);
 #endif
   for(i=0, font=fontdatabase;i<nfontdatabase;i++,font++) {
     if(font->usecount<0) continue;
@@ -111,7 +106,8 @@ int searchfontdatabase(char* ffpath, char* ffname,
 
 void cleanfontdatabase(void) {
   fontdesc* font;
-  int c,i;
+  int c;
+  int i,j;
 #ifdef DEBUGFONTDATABASE
   pfprot("(cleanfontdatabase ");
   j=0;
@@ -135,7 +131,6 @@ void cleanfontdatabase(void) {
       freemem(&(font->vffile));
       freemem(&(font->fonam));
       freemem(&(font->fopath));
-      freemem(&(font->vffontvect));
       font->usecount=-1;
       font->mch=-1;
     }
@@ -155,7 +150,7 @@ void killfontdatabase(void) {
       fontdatabase[i].usecount=0;
   cleanfontdatabase();
   freemem(&fontdatabase);
-  supfontdatabase=0;
+  maxfontdatabase=0;
   nfontdatabase=0;
 }
 
@@ -173,7 +168,7 @@ void dvibad(char* s) {
   }
 }
 
-void dvibytes(char *s, long  l) {
+void dvibytes(char *s, uchar  l) {
   if(l==0 || dvierrorflag) return;
   s[0]=0;  
   s[l] = '\0';  
@@ -285,14 +280,15 @@ static long hs[SMAX], vs[SMAX], ws[SMAX], xs[SMAX], ys[SMAX], zs[SMAX];
 static char comment[257], dvicomment[257];
 
 static double conv, vconv, sconv, svconv;
-static long  a, b, q, w, x, y, z, h, v;
-static long  spl,  mxh, mxv, lastpage;
-static int cfont;
+static long  /*dvimag ,*/a, b, q, w, x, y, z, h, v;
+static long  mag, spl,  mxh, mxv, lastpage;
+static int k, fint;
+
 static ushort s, mst;
 
 void fontdef(long fontnr) { 
   uchar  p, q;
-  int f,fdb;
+  int f,fdb,a;
   long dsz,scf,chksum;
   float fontmag;  
   fontdesc *font;
@@ -300,9 +296,6 @@ void fontdef(long fontnr) {
   char fontname[MAXPATHSTR];
   char messtr[MAXPATHSTR+20];
 
-#ifdef DEBUGFONTDATABASE
-  pfprot("(fontdef ...");
-#endif
   if (fontnr < 0)  {
     dvibad("negative fontnumber");
     return;
@@ -331,15 +324,14 @@ void fontdef(long fontnr) {
   if(fdb!=-1) {
     pfprot(" - fontdatabase");
     font=fontdatabase+fdb;
-    if(font->vffile!=NULL) /* look for involved pks/tfms */
-      vflookuppk(fdb);
-    font=fontdatabase+fdb; /* vflookup might cause reallocation of fontdatabase */
+    if (font->vffile!=NULL) /* look for involved pks */
+      vflookuppk(fdb,fontnr);
   } else {
     if (p==0) strcpy(ffpath, vfprefix);
     fdb=allocfontdesc(ffpath,fontname,dvimag,scf,dsz);
     font=fontdatabase+fdb;  
-    allocmem(&(font->chv),(MAXCHARS+1) * sizeof(chdesc)); 
-    memset(font->chv,0,(MAXCHARS+1) * sizeof(chdesc));  
+    allocmem(&(font->chv),(MAXFONTS+1) * sizeof(chdesc)); 
+    memset(font->chv,0,(MAXFONTS+1) * sizeof(chdesc));  
                                                /* unsused bitmaps=NULL */
                                                /* unused  fty  0 */
                                                /* unused dimensions 0*/
@@ -348,7 +340,6 @@ void fontdef(long fontnr) {
       tfmdef(fftuto,fdb,chksum);
     if(vffind(ffpath,fontname,fftuto)) {
       vfdef(fftuto,fdb,chksum,fontnr);
-      font=fontdatabase+fdb;  /* reallocation of fontdatabase */
     } else {
       if (p==0) strcpy(ffpath, fontprefix);
       if(pkfind(ffpath,fontname,fontmag,fftuto)) {
@@ -357,55 +348,48 @@ void fontdef(long fontnr) {
       }
     }
     reallocmem(&(font->chv),sizeof(chdesc)*(font->mch + 2));
+                                            /* +1 is enuough ?? */
   }  
-  /* assign an internal font numer, ie an index in fontvec */
-  f = fontnr % MAXFONTS; 
-  if(fontvect[f].fontdataptr != -1){
-    if(fontvect[f].dfn == fontnr) dvibad("double fontnumber");
-    for(f=MAXFONTS-1; f>=0; f--){
-      if(fontvect[f].fontdataptr == -1)  break;
-      if(fontvect[f].dfn == fontnr) dvibad("double fontnumber");
-    }  
+  f = fontnr & 0xff;  a = 0;
+  if ((fontnr >= MAXFONTS) || (fontvect[f].fontdataptr != -1)) do {
+    if (fontvect[a].fontdataptr == -1)  f = a;
+    else if (fontvect[a].dfn == fontnr)  {
+      dvibad("double fontnumber");
+      return;
+    }
+    a++;
+  } while (a<MAXFONTS);
+  if (fontvect[f].fontdataptr != -1) {
+    dvibad("too many fonts");
+    return;
   }
-  if(f<0) dvibad("too many fonts");
-  else {
-    font->usecount++;
-    fontvect[f].fontdataptr=fdb;
-    fontvect[f].dfn = fontnr;
-    pfprot("\n");
-  }
-#ifdef DEBUGFONTDATABASE
-  pfprot("... fontdef: done)");
-#endif
+  font->usecount++;
+  fontvect[f].fontdataptr=fdb;
+  fontvect[f].dfn = fontnr;
+  pfprot("\n");
 }
 
 
-#define Getfont(fontnr) (unigetfont(fontnr,fontvect,MAXFONTS))
-#define VFGetfont(fontnr,vffvect) (unigetfont(fontnr,vffvect,VFMAXFONTS))
-
-int unigetfont(long fontnr, fontdescvect* fvect, int fvectlen) {   
+int getintnr(long fontnr) {   
   int a, f, atleast;
-  f = fontnr % fvectlen;  
-  if (fvect[f].fontdataptr != -1) 
-    if (fvect[f].dfn == fontnr)
-      return(fvect[f].fontdataptr);
-  a = 0; atleast=-1;
+  f = fontnr & 0xff;  
+  if (fontvect[f].fontdataptr != -1) 
+    if (fontvect[f].dfn == fontnr)
+      return(f);
+  a = 0;
   do {
-    if(fvect[a].fontdataptr == -1) a++;
-      else if (fvect[a].dfn != fontnr) atleast=a++;
-        else return(fvect[a].fontdataptr);
-  } while (a < fvectlen);
+    if (fontvect[a].fontdataptr == -1) a++;
+      else if (fontvect[a].dfn != fontnr) atleast=a++;
+        else return(a);
+  } while (a < MAXFONTS);
   pfprot("\n %u ->",fontnr);
   dvibad("is not defined as a fontnumber");
-  if(atleast!=-1)
-    return(fvect[atleast].fontdataptr);
-  pfprot("\n fatal error: not a single valid font. sorry\n");
-  exit(1);
+  return(atleast);
 }
 
 
 
-static void pagebeg(pagelistelement* apage) {  
+static void pagebeg(void) {  
   uchar j;
   for (j = 0; j <= 9; j++)  /* count[j] = forget it */ dvinum(4);
   dvinum(4);
@@ -416,16 +400,12 @@ static void pagebeg(pagelistelement* apage) {
   z = 0;    
   h = 0;
   v = 0;
-  htex_beginpage(apage);
-  loadcolorstack(apage); /* assume its read already */
+  htex_beginpage(cpage);
 }
 
-static void pageend(pagelistelement* apage) {
+static void pageend(void) {
   if (s != 0)  pfprot("warning: stack not empty at eop");
   htex_endpage(); 
-  if(apage->num+1<pageanz)  /* save it worth */
-    if(pagelist[apage->num+1].cstackp<0)
-      savecolorstack(pagelist+apage->num+1);
 }
 
 
@@ -443,17 +423,14 @@ static void preamb(void) {
   if (newmag != 0) dvimag = newmag;
   conv = num / 254000.0 * ((double)xres / den) * (dvimag / 1000.0);
   vconv = num / 254000.0 * ((double)yres / den) * (dvimag / 1000.0);
-  l = dvibyte();  dvibytes(dvicomment, l);  
-  pfprot("%s\n", dvicomment);
-  pfverb("num %d den %d mag %d\n",num,den,dvimag);
+  l = dvibyte();  dvibytes(dvicomment, l);  pfprot("%s\n", dvicomment);
 #ifdef DEBUGDVI
-  pfprot("... preamb done)");
+  pfprot("num %d den %d mag %d .. preamb done)",num,den,dvimag);
 #endif
 }
 
-static int opentestdvi(void) {
+static int testdvi(void) {
   uchar l;
-  if(!dviopen()) return(0);
   dviposit(14L); 
   l=dvibyte();
   dvibytes(comment, l);
@@ -463,14 +440,6 @@ static int opentestdvi(void) {
   if(strcmp(comment,dvicomment)==0) return(1);
   else return(0);
 }
-
-int testdvi(void) {
-  int ret;
-  ret=opentestdvi();
-  dviclose();
-  return(ret);
-}  
-
   
 
 static void postamb(void) {
@@ -490,15 +459,14 @@ static void postamb(void) {
 }
 
 
-static void initpagelist(void) {
+static initpagelist(void) {
   short i;
   uchar o;
 #ifdef DEBUGDVI
-  pfprot("(initpagelist: pageanz %d ",pageanz);
+  pfprot("(initpagelist: pagenaz %d ",pageanz);
 #endif
   allocmem(&pagelist,MAX(1,pageanz)*sizeof(pagelistelement));
-  memset(pagelist,0,MAX(1,pageanz)*sizeof(pagelistelement)); /* all lists NULL */
-  for(i=0;i<pageanz;i++) pagelist[i].cstackp=-1;             /* all colorstacks invalid */
+  memset(pagelist,0,MAX(1,pageanz)*sizeof(pagelistelement));
   cpage=pagelist;
   if(pageanz==0) {
     dvibad("zero pages ?");
@@ -515,7 +483,7 @@ static void initpagelist(void) {
     }
     for (o = 0; o <= 9; o++)  pagelist[i].count[o] = dvinum(4);
     pagelist[i].num=i;
-    if(i==0) break;                           /*SCHLEIFENENDE HIER !!! */
+    if(i==0) break;                           /*SCHLEIGENENDE HIER !!! */
     /*pfprot("%3d %3d %3d %3d %3d %3d %3d %3d %3d %3d  \n",
       pagelist[i].count[0],pagelist[i].count[1],pagelist[i].count[2],
       pagelist[i].count[3],pagelist[i].count[4],pagelist[i].count[5],
@@ -539,7 +507,6 @@ short gotoprpage(short pn) {
     dvibad("corruptet pagelist");
   if(dvierrorflag)
     return(0);
-  /*if(pn==7) *((char*)NULL)=3; test for the signal catching */
   return(pn);
 }
 
@@ -571,7 +538,6 @@ short gotocccpage(double* ccc, short sp) {
  return(i);
 }
     
-void  readcolorstack(pagelistelement*); /* forward */
 
 
 void initdvi(void) { 
@@ -590,7 +556,7 @@ void initdvi(void) {
   dvierrorflag=0;
 
   allocmem(&fontvect,MAXFONTS*sizeof(fontdescvect));
-  for(i=0;i<MAXFONTS;i++) fontvect[i].fontdataptr=-1;
+  memset(fontvect,-1,MAXFONTS*sizeof(fontdescvect)); /* usecount -1 */
  
   if(!dviopen()) {
     dvibad("cant open dvifile"); 
@@ -623,10 +589,12 @@ void initdvi(void) {
 
 void killdvi(void) {
   int i;
+  int c;
 #ifdef DEBUGDVI
   pfprot("(killdvi ...");
 #endif 
   /* dviclose(); */
+  drawlistclear();
   if(fontvect!=NULL){
     for(i=0;i<MAXFONTS;i++) {
       if (fontvect[i].fontdataptr != -1)
@@ -636,10 +604,6 @@ void killdvi(void) {
   }
   freemem(&greytab);
   htex_kill();
-  for(i=0;i<pageanz ; i++){
-    freelrumem(&(pagelist[i].drawlist));
-    freemem(&(pagelist[i].cstack));
-  }
   freemem(&pagelist);
   pageanz=0;
   cpage=NULL;
@@ -649,21 +613,22 @@ void killdvi(void) {
 }
 
 
-void runvfmacro(chdesc* thechar);  /* forward */
+int  runvfmacro(chdesc* thechar);  /* forward */
 
-static void listchar(int c,fontdesc* font) {
+static void listchar(int c,int fontintnr) {
   
+  fontdesc *font;  
   chdesc *thechar;
   short hr,vr,ar,br;
   drawlistdata* data;
 
+  font = fontdatabase+fontvect[fontintnr].fontdataptr;
   if(font->mch < c) {
     pfverb(
     "(putchar: warning: skipping undefined charakter %d in %s)",c,font->fonam);
     q = 0;
     return;
   }
-  /* pfprot("(%c)",c); */
   /*pfprot("(listchar %d ... )",c);*/ 
   /*if(font->encoding)
      fprintf(prot,"%s",font->encoding[c]); */ 
@@ -675,16 +640,12 @@ static void listchar(int c,fontdesc* font) {
     htex_recordbits(h,v,1,1);  
   if(thechar->fty & PKTYPE) {  /* try pk first*/
     /*fprintf(prot," its a pk: c %d fin %d h %d v %d ...)",c,fontintnr,h,v);*/ 
-#ifdef LETSTRYCOLOR
-    if(dimmcolor==3) return;
-#endif
     q = thechar->tfw;
     if(fshrink == 1.0) {
       data=drawlistadd(*drawcharbmp);
       (*data).chr.h= LROUND(conv * h);
       (*data).chr.v= LROUND(vconv * v);
       (*data).chr.chdp=thechar; 
-      (*data).chr.c=dimmcolor; 
       return;
     }
     if(colors == BLACKNWHITE || fshrink < 1.0) { 
@@ -692,7 +653,6 @@ static void listchar(int c,fontdesc* font) {
       (*data).chr.h= LROUND(sconv * h);
       (*data).chr.v= LROUND(svconv * v);
       (*data).chr.chdp=thechar; 
-      (*data).chr.c=dimmcolor; 
       return;
     } 
     /*if shrinked and greyed { ... */
@@ -701,7 +661,6 @@ static void listchar(int c,fontdesc* font) {
     (*data).chr.h= LROUND(sconv * h);
     (*data).chr.v= LROUND(svconv * v);
     (*data).chr.chdp=thechar; 
-    (*data).chr.c=dimmcolor; 
     return;
   } /* end pk */
   if (thechar->fty & VFTYPE) {                            /* try vf */
@@ -711,6 +670,7 @@ static void listchar(int c,fontdesc* font) {
        return;
     }
     /* Debugging code: draw at least something */
+    /*
     /*br = LROUND(sconv * (thechar->tfw));
     hr = LROUND(sconv * h);
     vr = LROUND(svconv *v);
@@ -754,36 +714,22 @@ static void listchar(int c,fontdesc* font) {
 }
 
 
-#define MAXSPECIAL 500     /*lazy, but don't expect long specials */
-#define MAXSPECIALPROT 30  
+#define MAXSPECIAL 500  /*lazy, but don't expect long specials */
 char specstr[MAXSPECIAL];
 
 static void listspecial(void) {  
   long i;
-#ifdef DEBUGDVI
-  pfprot("(special: length %d)",spl);
-#endif
   if(spl>=MAXSPECIAL) {
-    pfverb("(special too long: <");
-    for(i = 0; i <MIN(spl,MAXSPECIALPROT); i++) 
-      pfverb("%c",0x7f &  dvibyte());
-    if(i<spl){
-      dviskip(spl-i);
-      pfverb(" ...>)");
-    } else
-      pfverb(">)");
+    pfprot("(special too long: ");
+    for (i = spl; i > 0; i--)  pfprot("%c",0x7f & dvibyte());
+    pfprot(")");
     return;
   }
   dvibytes(specstr,spl);
   if(checkndoHyperTeX(specstr,h,v)) return;
   if(checkndoEpsFile(specstr,h,v,sconv,svconv)) return;
-  if(checkndoColor(specstr)) return;
   /* insert other specials here */
-  specstr[MIN(MAXSPECIALPROT,MAXSPECIAL)]=0;
-  if(spl<=MAXSPECIALPROT)
-    pfverb("(special <%s> ignored)",specstr);
-  else
-    pfverb("(special <%s ...> ignored)",specstr);
+  pfverb("(special <%s> ignored)",specstr);  
 };
 
 
@@ -801,9 +747,6 @@ static void listrule(void) {
  
   /*fprintf(prot,
        "(listrule: le %5.1f bo %5.1f wi %5.1f hi %5.1f) ",le,bo,wi,hi);*/ 
-#ifdef LETSTRYCOLOR
-  if(dimmcolor==3) return; /* dimmned completely */
-#endif
   if(fshrink == 1.0) {        /* do it like they told me ... not shrunken*/  
     wi=LCEIL(wi); hi=LCEIL(hi);
     data=drawlistadd(*drawruleor);
@@ -811,7 +754,7 @@ static void listrule(void) {
     (*data).rect.y=bo-hi+1;
     (*data).rect.w=wi;
     (*data).rect.h=hi;
-    (*data).rect.c= vgadimm(BLACKCOL,dimmcolor);
+    (*data).rect.c=BLACKCOL;
     return;
   }   
   if(colors==BLACKNWHITE) {                     /* shrunken, blacknwhite*/
@@ -822,7 +765,7 @@ static void listrule(void) {
     (*data).rect.y=bo-hi+1;
     (*data).rect.w=wi;
     (*data).rect.h=hi;
-    (*data).rect.c=vgadimm(BLACKCOL,dimmcolor);
+    (*data).rect.c=BLACKCOL;
     return;
   }                                                    /* is greyscaled*/
   data=drawlistadd(*drawruleor);
@@ -830,7 +773,7 @@ static void listrule(void) {
   (*data).rect.y=bo-LFLOOR(hi)+1;
   (*data).rect.w=LFLOOR(wi);
   (*data).rect.h=LFLOOR(hi);
-  (*data).rect.c=vgadimm(BLACKCOL,dimmcolor);
+  (*data).rect.c=BLACKCOL;
   gs=(uchar)(LROUND((COLORS_PER_GREY-1)*(wi-LFLOOR(wi)))); 
   if(wi < 1) gs=MAX(1,gs);
   data=drawlistadd(*drawruleor);
@@ -838,7 +781,7 @@ static void listrule(void) {
   (*data).rect.y=bo-LROUND(hi)+1;
   (*data).rect.w=1;
   (*data).rect.h=LROUND(hi);
-  (*data).rect.c=vgadimm(gs,dimmcolor); 
+  (*data).rect.c=gs; 
   gs=(uchar)(LROUND((COLORS_PER_GREY-1)*(hi-LFLOOR(hi))));  
   if(hi < 1) gs=MAX(1,gs);
   data=drawlistadd(*drawruleor);
@@ -846,18 +789,18 @@ static void listrule(void) {
   (*data).rect.y=bo-LFLOOR(hi);
   (*data).rect.w=LROUND(wi);
   (*data).rect.h=1;
-  (*data).rect.c=vgadimm(gs,dimmcolor); 
+  (*data).rect.c=gs; 
   /*pfprot("did id\n");*/
 }
 
 
 /************************************************************/
 /* Macro processing: Striktly non-recursive, all global !!  */
-/* ... Hm. V00.04: make it recursive by backing things up   */
 
 static long   macropos;
 static uchar* macrodata;
 static long   macrolen;
+static long   vffint;
 
 uchar macrobyte(void)  {  
   if(macrolen-macropos < 1) return 0L;
@@ -889,24 +832,20 @@ long macroint(uchar b)  {
 }
 
 
-void runvfmacro(chdesc* thechar){
+int  runvfmacro(chdesc* thechar){
   uchar o,c;
+  int i,ishr;
   ushort d1,d2;
-  int vfcfont;
-  long f, scf;
-  long   omacropos,omacrolen;
-  uchar* omacrodata;
+  long f, vffnr, vffint;
+
 
-  omacrolen=macrolen;
-  omacropos=macropos;
-  omacrodata=macrodata;
   macropos=0;
   macrodata=thechar->macro;
   macrolen=thechar->mlen;
-  vfcfont=cfont; /* global from readdvi: vf we're in */
-  scf=FD(vfcfont)->foscf;
-  cfont=VFGetfont(FD(vfcfont)->vffirst,FD(vfcfont)->vffontvect);
- 
+  vffint=fint;
+  vffnr=fontvect[vffint].dfn;
+  fint=getintnr((1+vffnr)*MAXFONTS + thechar->lastf);
+
 #ifdef DEBUGMACRO
   pfprot("(run macro c %u in %s ... ",
 	 thechar->ch, fontdatabase[thechar->fontdataptr].fonam);
@@ -920,25 +859,23 @@ void runvfmacro(chdesc* thechar){
        ws[s - 1] = w;	xs[s - 1] = x;	ys[s - 1] = y; zs[s - 1] = z;
   } else  dvibad("macro: stack overflow");  
   
-  q=w=x=y=z=0;
+  q=0;
   while (macropos<macrolen) {
     o = macrobyte();
     /* pfprot("(%d)",o); */
     if (o <= 127) {
-       listchar(o,FD(cfont));  h += q;
+       listchar(o,fint);  h += q;
     } else if (o >= 171 && o <= 234) {
-	 cfont=VFGetfont(o-171,FD(vfcfont)->vffontvect);
+	 fint=getintnr(o-171+(1+vffnr)*MAXFONTS);
     } else
     switch (o) {
     case 128:  case 129:  case 130:  case 131:
-      c = macronum(o - 127);  listchar(c,FD(cfont));  h += q;  break;
-    case 132:  a = scaled(macroint(4), scf);
-      b = scaled(macroint(4), scf);
+      c = macronum(o - 127);  listchar(c,fint);  h += q;  break;
+    case 132:  a = macroint(4);  b = macroint(4);
       listrule();  h += b;  break;
     case 133:  case 134:  case 135:  case 136:
-      c = macronum(o - 132);  listchar(c,FD(cfont));  break;
-    case 137:  a = scaled(macroint(4), scf);
-      b = scaled(macroint(4), scf);
+      c = macronum(o - 132);  listchar(c,fint);  break;
+    case 137:  a = macroint(4);  b = macroint(4);
       listrule();  break;
     case 138: break;
     case 139: dvibad("macro: unexpectet bop"); break;
@@ -950,24 +887,24 @@ void runvfmacro(chdesc* thechar){
 	w = ws[s - 1];	x = xs[s - 1];	y = ys[s - 1];	z = zs[s - 1];	s--;
       } else  dvibad("macro: stack underflow");  break;
     case 143:  case 144:  case 145:  case 146:
-      h += scaled(macroint(o - 142), scf);  break;
+      h += macroint(o - 142);  break;
     case 147:  h += w;  break;
     case 148:  case 149:  case 150:  case 151:
-      w = scaled(macroint(o - 147), scf);  h += w;  break;
+      w = macroint(o - 147);  h += w;  break;
     case 152:  h += x;  break;
     case 153:  case 154:  case 155:  case 156:
-      x = scaled(macroint(o - 152), scf);  h += x;  break;
+      x = macroint(o - 152);  h += x;  break;
     case 157:  case 158:  case 159:  case 160:
-      v += scaled(macroint(o - 156), scf);  break;
+      v += macroint(o - 156);  break;
     case 161:  v += y;  break;
     case 162:  case 163:  case 164:  case 165:
-      y = scaled(macroint(o - 161), scf);  v += y;  break;
+      y = macroint(o - 161);  v += y;  break;
     case 166:  v += z;  break;
     case 167:  case 168:  case 169:  case 170:
-      z = scaled(macroint(o - 166), scf);  v += z;  break;
+      z = macroint(o - 166);  v += z;  break;
     case 235:  case 236:  case 237:  case 238:
       f = macronum(o - 234);
-      cfont=VFGetfont(f,FD(vfcfont)->vffontvect);
+      fint=getintnr(f+(1+vffnr)*MAXFONTS);
       break;
     case 239:  case 240:  case 241:  case 242:
       spl = macronum(o - 238);
@@ -987,18 +924,18 @@ void runvfmacro(chdesc* thechar){
     } /* end switch o */
   }
 
+  macropos=0;
+  macrolen=0;
+  fint=vffint;
   if (s > 0) {
     h = hs[s - 1];  v = vs[s - 1];
     w = ws[s - 1];	x = xs[s - 1];	y = ys[s - 1];	z = zs[s - 1];	s--;
   } else  dvibad("macro: stack underflow"); 
   
-  macrolen=omacrolen;
-  macropos=omacropos;
-  macrodata=omacrodata;
-  cfont=vfcfont;
 #ifdef DEBUGMACRO
   pfprot("... macro)");
 #endif
+
 }
 
 
@@ -1008,48 +945,83 @@ void runvfmacro(chdesc* thechar){
 /* finally lets read a page ...      */
 
 
-void  readpage(pagelistelement* apage){
+int  readpage(short pn, float fshr, uchar col, uchar dps, int force){
   uchar o,c;
+  int i,ishr;
   ushort d1,d2;
   long f;
 
-  if(apage->drawlist!=NULL) return;
-  readcolorstack(apage); /* make sure, colorstack is in pagelist */
-
-  if(!opentestdvi()) {
-    dvibad("dvifile changed/disappeared? reload!");
-    return;
-  }
 #ifdef DEBUGDVI
   pfprot("(readpage ...");
 #endif 
 
-  sconv=conv/apage->fshr;
-  svconv=vconv/apage->fshr;
-  drawlistinit(apage);
-
-  gotoprpage(apage->num);
-  if(dvierrorflag) return;
-  pfprot("[%d",apage->num);
-  pagebeg(apage);
+  if(!dviopen()) {
+    dvibad("dvifile disappeard"); 
+  }
+  if(!testdvi()) {
+    pfprot("\ndvifile has changed? reload\n");
+    killdvi(); /* dont cause rerendering eps-files */
+    initdvi();
+    dviopen();
+    force=1;         /* late edit ?*/
+  }
+ 
+  fshr=MAX(MINSHRINK,MIN(MAXSHRINK,fshr));
+  if(ishrinkonly)
+    fshr=MAX(1,LROUND(fshr));
+  else
+    fshr=(ROUND(100*fshr)/100.0); 
+  if(fshr != fshrink || col != colors || dps!=doeps) {
+    force=1;
+    killgscript();
+    initgscript();
+  }
+  if(force) {
+    if(col == GREYSCALE) {
+      freemem(&greytab);
+      ishr=ROUND(fshr);  
+      allocmem(&greytab,(ishr+1)*(ishr+1)+1); /* fuck +1 */
+      for(i=0;i<=ishr*ishr;i++) 
+        greytab[i]=ROUNDUP(i*(COLORS_PER_GREY-1),ishr*ishr);
+      for(;i<=(ishr+1)*(ishr+1);i++) 
+        greytab[i]=COLORS_PER_GREY-1;
+    } else col=BLACKNWHITE;
+  }
+  pn=gotoprpage(pn);
+  if(!force)                             /* protect for cpage==NULL */
+  if(pn==cpage->num){
+    dviclose();
+#ifdef DEBUGDVI
+    pfprot("... not realy readpage)");
+#endif 
+    return(0);
+  }
+  cpage=pagelist+pn;
+  fshrink=fshr;
+  colors=col;
+  doeps=dps;
+  sconv=conv/fshr;
+  svconv=vconv/fshr;
+  drawlistclear();
+  if(dvierrorflag) return(1);
+  pfprot("[%d",cpage->num);
+  pagebeg();
   q=0;     
   o = dvibyte();
   while (o != 140 && dvierrorflag ==0) {
-#ifdef DEBUGDVI
-     pfprot("(%d)",o); 
-#endif
+    /*pfprot("(%d)",o);*/
     if (o <= 127) {
-       listchar(o,FD(cfont));  h += q;
+       listchar(o,fint);  h += q;
     } else if (o >= 171 && o <= 234) {
-	 cfont=Getfont(o-171);
+	 fint=getintnr(o-171);
     } else
     switch (o) {
     case 128:  case 129:  case 130:  case 131:
-      c = dvinum(o - 127);  listchar(c,FD(cfont));  h += q;  break;
+      c = dvinum(o - 127);  listchar(c,fint);  h += q;  break;
     case 132:  a = dviint(4);  b = dviint(4);
       listrule();  h += b;  break;
     case 133:  case 134:  case 135:  case 136:
-      c = dvinum(o - 132);  listchar(c,FD(cfont));  break;
+      c = dvinum(o - 132);  listchar(c,fint);  break;
     case 137:  a = dviint(4);  b = dviint(4);
       listrule();  break;
     case 138: break;
@@ -1078,9 +1050,7 @@ void  readpage(pagelistelement* apage){
     case 167:  case 168:  case 169:  case 170:
       z = dviint(o - 166);  v += z;  break;
     case 235:  case 236:  case 237:  case 238:
-      f = dvinum(o - 234);  
-      cfont=Getfont(f);
-      break;
+      f = dvinum(o - 234);  fint=getintnr(f);  break;
     case 239:  case 240:  case 241:  case 242:
       spl = dvinum(o - 238);  listspecial();  break;
     case 243:  case 244:  case 245:  case 246:
@@ -1096,16 +1066,15 @@ void  readpage(pagelistelement* apage){
     o = dvibyte();
   } 
   htex_scalebox(sconv,svconv);
-  pageend(apage);
+  pageend();
   pfprot("] ");
   dviclose();
   if(dvierrorflag)   
-    drawlistinit(apage);
-  drawlistfix();
+    drawlistclear();
 #ifdef DEBUGDVI
   pfprot("... done readpage)");
 #endif 
-  return;
+  return(1);
 }    
     
 
@@ -1224,10 +1193,12 @@ void settextmark(void){
 }  
 
 
-void searchsetq(int c,fontdesc *font) {
+void searchsetq(int c,int fontintnr) {
   
+  fontdesc *font;  
   chdesc *thechar;
 
+  font = fontdatabase+fontvect[fontintnr].fontdataptr;
   if(font->mch < c) {
     q = 0;
   } else {
@@ -1240,12 +1211,14 @@ void searchsetq(int c,fontdesc *font) {
 }
 
 
-void searchchar(int c,fontdesc *font) {
+void searchchar(int c,int fontintnr) {
   
+  fontdesc *font;
   chdesc *achar;  
   int alen,i,x1pxl,x2pxl,y1pxl,y2pxl;
   char *astr;
 
+  font = fontdatabase+ fontvect[fontintnr].fontdataptr;
   q=0;
   if(font->mch < c)  return;
   achar=font->chv+c;
@@ -1313,12 +1286,12 @@ void searchreaddvi(int *spage, long *spos) {
   dpage=*spage-1;
   startpos=*spos;
 #ifdef DEBUGDVI
-  pfprot("(searchreaddvi spage %d spos %d ...",*spage,*spos);
+  pfprot("(searchraeddvi spage %d spos %d ...",*spage,*spos);
 #endif
   do { /* run through pages */
     dpage++;
     if(dpage != gotoprpage(dpage)) break;
-    sprintf(messtr,"      [%ld]",MAX(-9999,MIN(pagelist[dpage].count[0],9999)));
+    sprintf(messtr,"      [%d]",MAX(-9999,MIN(pagelist[dpage].count[0],9999)));
     if(proceedthis(messtr)) break; 
     dpos=0;
     dviskip(44L); /* counts and 4*/
@@ -1329,13 +1302,13 @@ void searchreaddvi(int *spage, long *spos) {
        switch (o) {
       case 128:  case 129:  case 130:  case 131:
         c = dvinum(o - 127);   
-        if(dpos>=startpos) searchchar(c,FD(cfont));
-        searchsetq(c,FD(cfont));   
+        if(dpos>=startpos) searchchar(c,fint);
+        searchsetq(c,fint);   
         h += q;  break;
       case 132:  a = dviint(4);  b = dviint(4); h += b;  break;
       case 133:  case 134:  case 135:  case 136:
         c = dvinum(o - 132);  
-        if(dpos>=startpos) searchchar(c,FD(cfont));  break;
+        if(dpos>=startpos) searchchar(c,fint);  break;
       case 137:  a = dviint(4);  b = dviint(4); break;
       case 138: break;
       case 139: dvibad("unexpectet bop"); break;
@@ -1363,9 +1336,7 @@ void searchreaddvi(int *spage, long *spos) {
       case 167:  case 168:  case 169:  case 170:
         z = dviint(o - 166);  v += z;  break;
       case 235:  case 236:  case 237:  case 238:
-        f = dvinum(o - 234);  
-        cfont=Getfont(f);
-        break;
+        f = dvinum(o - 234);  fint=getintnr(f);  break;
       case 239:  case 240:  case 241:  case 242:
         spl = dvinum(o - 238); dviskip((long)spl); 
         break;
@@ -1378,12 +1349,12 @@ void searchreaddvi(int *spage, long *spos) {
         break;
       default:
         if (o <= 127) { 
-          if(dpos>=startpos) searchchar(o,FD(cfont));
-          searchsetq(o,FD(cfont));  
+          if(dpos>=startpos) searchchar(o,fint);
+          searchsetq(o,fint);  
           h += q;
         } else
           if (o >= 171 && o <= 234) {
-            cfont=Getfont(o-171);
+	    fint=getintnr(o-171);
           } break;
       } /* end switch o */
       dpos++;
@@ -1412,17 +1383,12 @@ const char* searchdvi(char* sstr, int* spage, long* spos){
 #ifdef DEBUGDVI
   pfprot("(searchdvi sstr (%d) %s ... ",ssl,sstr);
 #endif
-  if(!opentestdvi()) {
-    dvibad("dvifile changed/disappeared? reload!");
-    return(0);
-    /*  
+  if(!dviopen()) return(0);
+  if(!testdvi()) {
+    pfprot("\ndvifile has changed? reload\n");
     killdvi();
     initdvi();
-    if(!opentestdvi()) {
-      dvibad("dvifile reloading failed!");
-      return(0);
-    }
-    */
+    dviopen();
   }
   boundx1pxl=MMTOPXL(visfmk->lrandmm)-MMTOPXL(visfmk->hoffmm);
   boundy1pxl=MMTOPXL(visfmk->orandmm)-MMTOPXL(visfmk->voffmm);
@@ -1480,10 +1446,12 @@ const char* searchdvi(char* sstr, int* spage, long* spos){
 /*****************************************************************************/
 
 
-void anchorcharq(int c, fontdesc *font) {
+void anchorcharq(int c,int fontintnr) {
   
+  fontdesc *font;  
   chdesc *thechar;
 
+  font = fontdatabase+fontvect[fontintnr].fontdataptr;
   if(font->mch < c) {q=0; return;}
   thechar=font->chv+c;
   if (thechar->fty == TFMTYPE)  /* is only tfm !!! */    
@@ -1498,22 +1466,18 @@ void anchorcharq(int c, fontdesc *font) {
 }
 
 
-void readanchors(int page) {
+readanchors(int page) {
   uchar o,c;
+  int i,j,an;
   ushort d1,d2;
-  long f;
+  long f,startpos;
 
-  if(!opentestdvi()) {
-    dvibad("dvifile changed/disappeared? reload!");
-    return;
-    /*
+  if(!dviopen()) return;
+  if(!testdvi()) {
+    pfprot("\ndvifile has changed? reload\n");
     killdvi();
     initdvi();
-    if(!opentestdvi()) {
-      dvibad("dvifile reloading failed!");
-      return;
-    }
-    */
+    dviopen();
   }
   if(page != gotoprpage(page)){ 
     dviclose();
@@ -1528,7 +1492,7 @@ void readanchors(int page) {
     switch (o) {
     case 128:  case 129:  case 130:  case 131:
       c = dvinum(o - 127);
-      anchorcharq(c,FD(cfont));   
+      anchorcharq(c,fint);   
       h += q;  break;
     case 132:  a = dviint(4);  b = dviint(4);  
       if ((b > 0) && (a>0)) 
@@ -1537,7 +1501,7 @@ void readanchors(int page) {
       break;
     case 133:  case 134:  case 135:  case 136:
       c = dvinum(o - 132);
-      anchorcharq(c,FD(cfont));  
+      anchorcharq(c,fint);  
       break;
     case 137:  a = dviint(4);  b = dviint(4); 
       if ((b > 0) && (a>0)) 
@@ -1569,9 +1533,7 @@ void readanchors(int page) {
     case 167:  case 168:  case 169:  case 170:
       z = dviint(o - 166);  v += z;  break;
     case 235:  case 236:  case 237:  case 238:
-      f = dvinum(o - 234);  
-      cfont=Getfont(f);
-      break;
+      f = dvinum(o - 234);  fint=getintnr(f);  break;
     case 239:  case 240:  case 241:  case 242:
       spl = dvinum(o - 238);
       if(spl<MAXSPECIAL) {
@@ -1589,11 +1551,11 @@ void readanchors(int page) {
       break;
     default:
       if (o <= 127) { 
-        anchorcharq(o,FD(cfont));  
+        anchorcharq(o,fint);  
         h += q;
       } else
         if (o >= 171 && o <= 234) {
-          cfont=Getfont(o-171);
+	  fint=getintnr(o-171);
       } 
       break;
       } /* end switch o */
@@ -1617,7 +1579,7 @@ int  searchhref(char* href, int* spage, int* xpxl, int* ypxl){
     if(an== -1) {
       for(*spage=0;*spage<pageanz;(*spage)++) {
         if(pagelist[*spage].anchorsdone!=DONE) {
-          sprintf(messtr,"      [%ld]",
+          sprintf(messtr,"      [%d]",
             MAX(-9999,MIN(pagelist[*spage].count[0],9999)));
           if(proceedthis(messtr)) break; 
           readanchors(*spage);
@@ -1634,88 +1596,5 @@ int  searchhref(char* href, int* spage, int* xpxl, int* ypxl){
 }
 
 
-/****************************************************************************/
-/* set up colorstack ... slow, but how else should one do ?                 */
-/****************************************************************************/
-
-void readcolorstack(pagelistelement* apage) {
-  uchar o;
-  ushort d1,d2;
-  int page;
-  long spl;
-
-#ifndef LETSTRYCOLOR
-  return();
-#endif
-  if(apage->cstackp>=0) return; 
-  killcolorstack();
-  if(apage->num==0) {
-    savecolorstack(apage);
-    return;
-  }
-  for(page=apage->num;page>=0;page--) /* done up to where? */
-    if(pagelist[page].cstackp>=0) break;
-  if(page>=0)
-    loadcolorstack(pagelist+page);
-  else 
-    page=0;
-  if(!opentestdvi()) {
-    dvibad("dvifile changed/disappeared? reload!");
-    return;
-  }
-  for(;page<apage->num;page++){          /* go through pages */
-    /*pfprot("(read colorstack %d)",page); */
-    if(page != gotoprpage(page)){ 
-      dviclose();
-      return;
-    }
-    dviskip(44L); /* counts and 4*/
-    o = dvibyte(); 
-    while (!dvierrorflag && o != 140) {
-      /* fprintf(prot,"(%d)",o);*/ 
-      switch (o) {
-      case 128:  case 129:  case 130:  case 131: 
-        dvinum(o - 127); break;
-      case 132:  
-        dviint(4);  dviint(4); break;
-      case 133:  case 134:  case 135:  case 136:
-        dvinum(o - 132); break;
-      case 137:  
-        a = dviint(4);  b = dviint(4); break;
-      case 139: dvibad("unexpectet bop"); break;
-      case 143:  case 144:  case 145:  case 146:
-        dviint(o - 142);  break;
-      case 148:  case 149:  case 150:  case 151:
-        dviint(o - 147); break;
-      case 153:  case 154:  case 155:  case 156:
-        dviint(o - 152); break;
-      case 157:  case 158:  case 159:  case 160:
-        dviint(o - 156);  break;
-      case 162:  case 163:  case 164:  case 165:
-        dviint(o - 161);  break;
-      case 167:  case 168:  case 169:  case 170:
-        dviint(o - 166);  break;
-      case 235:  case 236:  case 237:  case 238:
-        dvinum(o - 234);  break;
-      case 239:  case 240:  case 241:  case 242:
-        spl = dvinum(o - 238);
-        if(spl<MAXSPECIAL) {
-          dvibytes(specstr,spl);
-          checkndoColor(specstr);
-        } else
-          dviskip((long)spl); 
-        break;
-      case 243:  case 244:  case 245:  case 246:
-        dvinum(o-242); dviskip(12L); 
-        d1 = dvibyte();  d2 = dvibyte();  dviskip((long)(d1 + d2)); break;
-      default:
-        break;
-      } /* end switch o */
-      o = dvibyte();
-    } /* end a page */
-    savecolorstack(pagelist+page+1);
-  } /* end through pages */
-  dviclose();
-}  
 
 
