@@ -7,7 +7,7 @@
 #include "defs.h"
 
 
-/*#define DEBUGPK */
+/* #define DEBUGPK */
 
 
 FILE* pkfile;
@@ -117,7 +117,7 @@ int pkpackednum(void){
 }
 
 
-void setpkname(char* fn, float fm, int delta, char* result) {
+setpkname(char* fn, float fm, int delta, char* result) {
   char buff[MAXPATHSTR];
   int i,j;
 
@@ -154,32 +154,30 @@ void setpkname(char* fn, float fm, int delta, char* result) {
   /*fprintf(prot,"%s)",ffname);*/
 }
 
-#ifdef KPATHSEA  /* use kpathsea if wanted */
-int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {  
-  int foundfile;
-  FILE* fofile;
-  kpse_glyph_file_type font_ret;
-  char *kpsename=NULL;
-  unsigned dpi;
 
-  dpi = kpse_magstep_fix((unsigned) (fontmag +.5), xres, NULL);
-  kpsename = kpse_find_pk(fontname, dpi, &font_ret);
-  foundfile = (kpsename!=NULL);
-  if(kpsename){
-    strncpy(fftuto, kpsename,MAXPATHSTR-1);
-    fftuto[MAXPATHSTR-1]=0;
-    freemem(&kpsename);         
+int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {  
+  char ffname[MAXPATHSTR];
+  int delta, foundfile;
+  FILE* fofile;
+  
+#ifdef KPATHSEA                            /* use kpathsea if wanted */
+  kpse_glyph_file_type font_ret;
+  char *name=NULL;
+  unsigned dpi;
+  
+  dpi = kpse_magstep_fix ((unsigned) (fontmag +.5), xres, NULL);
+  name = kpse_find_pk (fontname, dpi, &font_ret);
+  foundfile = (name!=NULL);
+  if(name){
+    strcpy(fftuto, name);
+    freemem(&name);         
     if (!(strcmp(fontname,font_ret.name)==0)) 
           pfprot(" - using %s at %d instead ", font_ret.name, font_ret.dpi);
     else if (!kpse_bitmap_tolerance ((double)font_ret.dpi, (double) dpi))
           pfprot(" - loading at %d ", font_ret.dpi);
     } 
-
-#else   /* use my own subs (slow) */
-int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {  
-  char ffname[MAXPATHSTR];
-  int delta, foundfile;
-  FILE* fofile;
+         
+#else                                             /* use my own subs (slow) */
 
   setpkname(fontname,fontmag,0,ffname);
   foundfile=msearch(ffpath,ffname,fftuto);
@@ -193,7 +191,8 @@ int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {
        if(foundfile!=0) break;
      }
   }
-#endif /* tail of pkfind */
+#endif
+
   if(foundfile==0) { 
         pfprot(" - no PKfile "); 
         return(0);
@@ -212,23 +211,24 @@ int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {
 
 
 int pkdef(char* fftuto,int fdb,long chksum)  {  
-  long l, goonaddr, fpwidth, dchksum, needmem;
+  long a, l, goonaddr, fpwidth, dchksum, needmem;
   unsigned long w,h;  
   uchar b, bb;
-  uchar terminate;  short i, c;  
+  uchar terminate;  short i, j, c;  
   chdesc *achar;
+  fontdesc *font;
   int mchpk;
   
 #ifdef DEBUGPK
   pfprot("(pkdef: ");
 #endif
-  allocmem(&(FD(fdb)->pkfile),strlen(fftuto)+1);
-  strcpy(FD(fdb)->pkfile, fftuto);
+  font=fontdatabase+fdb;
+  allocmem(&(font->pkfile),strlen(fftuto)+1);
+  strcpy(font->pkfile, fftuto);
   pkopen(fftuto);
 #ifdef DEBUGPK
-  pfprot(" %s - charakters: ",FD(fdb)->fonam);
+  pfprot(" %s - charakters: ",font->fonam);
 #endif
-  l=fpwidth=w=h=c=0;
   mchpk=-1;
   terminate = 0;
   do {  b = pkn1();
@@ -263,11 +263,11 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
     case 7:  l = pki4();  c = pki4();  break;
     }
     goonaddr=l+pktell();
-    /* fprintf(prot,"(goon off %u)",l);fflush(prot); */ 
-    if(c>=MAXCHARS) {
+    /* fprintf(prot,"(goon off %u)",l);fflush(prot); */	
+    if(c>255) {
       pfprot(" -  ignoring character %d ",c);
     } else { /* code < 256 */
-      achar = FD(fdb)->chv+c;
+      achar = font->chv+c;
 #ifdef DEBUGPK
       pfprot(" c %d at 0x%x ", c, achar); 
 #endif
@@ -289,7 +289,7 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
       }
       needmem=((long)h)*((long)ROUNDUP(w,BITS_PER_BMUNIT/GREYSCALE))
               *BYTES_PER_BMUNIT;
-      if (w > 0x7fff || h > 0x7fff || needmem > maxlinmem){
+      if (w > 0x7fff || h > 0x7fff || needmem > MAXLINMEM){
         pfprot(
        " - ignoring character %d (w=%ud h=%ud mem=%ud) ",
         c, w,h,needmem); 
@@ -302,7 +302,7 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
         achar->bmp.type=BLACKNWHITE;
         achar->bmp.bits= NULL;
         achar->bmp2.bits= NULL;
-        achar->tfw = scaled(fpwidth,FD(fdb)->foscf);
+        achar->tfw = scaled(fpwidth,font->foscf);
         achar->addr = pktell();
         /* fprintf(prot,"width %d hight %d hof %d vof %d \n",
          w,h,achar->hof,achar->vof); */
@@ -318,133 +318,134 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
 #endif
   if (mchpk < 0) {
     pfprot(" - PKfile in error ");
-    freemem(&(FD(fdb)->pkfile));
+    freemem(&(font->pkfile));
     return(0);
   } else  pfverb(" - PKfile ok ");
-  if (mchpk > FD(fdb)->mch)  FD(fdb)->mch=mchpk;
+  if (mchpk > font->mch)  font->mch=mchpk;
   return(1);
 }
 
 
 void pkloadchar(chdesc *thechar){
+	int	 n;
         uchar    theflag;
-        char    paint_switch;
+        char	paint_switch;
         char*   pkfilen;
-        int     i, j;
-        int     row_bit_pos;
-        BMUNIT  *cp;
-        BMUNIT  word;
-        int     word_weight, bytes_wide;
-        int     rows_left, h_bit, count;
+	int	i, j;
+	int	row_bit_pos;
+	BMUNIT	*cp;
+	BMUNIT	word;
+	int	word_weight, bytes_wide;
+	int	rows_left, h_bit, count;
 
         theflag = thechar->flag;
-        pkdynf = theflag  >> 4;
+	pkdynf = theflag  >> 4;
         pkfilen=(fontdatabase+thechar->fontdataptr)->pkfile;
 #ifdef DEBUGPK
-        pfprot("(pkloadchar: charpt 0x%x,fontdataptr %d char %d ...",
+	pfprot("(pkloadchar: charpt 0x%x,fontdataptr %d char %d ...",
            thechar,thechar->fontdataptr,thechar->ch); 
 #endif
         pkopen(pkfilen);
         pkposit(thechar->addr);
-        paint_switch = ((theflag & 8) != 0);
+	paint_switch = ((theflag & 8) != 0);
 #ifdef DEBUGPK
         pfprot("width %d hight %d hof %d vof %d ",
                  thechar->bmp.w,thechar->bmp.h,
                  thechar->hof,thechar->vof); 
 #endif
-        /*
-         * now read rest of character code
-         */
+	/*
+	 * now read rest of character code
+	 */
         
-        alloc_bitmapbw(&thechar->bmp);
-        cp = thechar->bmp.bits;
+	alloc_bitmapbw(&thechar->bmp);
+	cp = thechar->bmp.bits;
 
+       
         bytes_wide = thechar->bmp.bmu_wide * BYTES_PER_BMUNIT;
-        pkbitpos = -1;
-        word=0;
-        if (pkdynf == 14) {     /* get raster by bits */
-            /* fprintf(prot,"raster: "); */
+	pkbitpos = -1;
+	if (pkdynf == 14) {	/* get raster by bits */
+	    /* fprintf(prot,"raster: "); */
             clear_bitmap(&thechar->bmp);
-            for (i = 0; i < thechar->bmp.h; i++) {      /* get all rows */
-                cp = ADD(thechar->bmp.bits, i * bytes_wide);
-                row_bit_pos = BITS_PER_BMUNIT;
-                for (j = 0; j < thechar->bmp.w; j++) {  /* get one row */
-                    if (--pkbitpos < 0) {
-                        word = pkn1();
-                        pkbitpos = 7;
-                    }
-                    if (--row_bit_pos < 0) {
-                        cp++;
-                        row_bit_pos = BITS_PER_BMUNIT - 1;
-                    }
-                    if (word & (1 << pkbitpos)) *cp |= ((BMUNIT)1) << row_bit_pos;
-                }
-            }
-        }
-        else {          /* get packed raster */
-            /* fprintf(prot,"packed raster \n"); fflush(prot); */
+	    for (i = 0; i < thechar->bmp.h; i++) {	/* get all rows */
+		cp = ADD(thechar->bmp.bits, i * bytes_wide);
+		row_bit_pos = BITS_PER_BMUNIT;
+		for (j = 0; j < thechar->bmp.w; j++) {  /* get one row */
+		    if (--pkbitpos < 0) {
+			word = pkn1();
+			pkbitpos = 7;
+		    }
+		    if (--row_bit_pos < 0) {
+			cp++;
+			row_bit_pos = BITS_PER_BMUNIT - 1;
+		    }
+		    if (word & (1 << pkbitpos)) *cp |= 1 << row_bit_pos;
+		}
+	    }
+	}
+	else {		/* get packed raster */
+	    /* fprintf(prot,"packed raster \n"); fflush(prot); */
             rows_left = thechar->bmp.h;
-            h_bit = thechar->bmp.w;
-            pkrepcount = 0;
-            word_weight = BITS_PER_BMUNIT;
-            word = 0;
-            while (rows_left > 0) {
-              /* fprintf(prot,"rl %d ",rows_left); fflush(prot); */
-              count = pkpackednum();
+	    h_bit = thechar->bmp.w;
+	    pkrepcount = 0;
+	    word_weight = BITS_PER_BMUNIT;
+	    word = 0;
+	    while (rows_left > 0) {
+	      /* fprintf(prot,"rl %d ",rows_left); fflush(prot); */
+	      count = pkpackednum();
               /* fprintf(prot,"count %d \n",count); fflush(prot); */
               while (count > 0) {
                 /* fprintf(prot,"ct %d hb %d ww %d \n",
                    count,h_bit,word_weight); fflush(prot); */
-              if (count < word_weight && count < h_bit) {
-                h_bit -= count;
-                word_weight -= count;
-                if (paint_switch)
-                  word |= bit_masks[count] << word_weight;
-                  count = 0;
-              }
-              else if (count >= h_bit && h_bit <= word_weight) {
-                if (paint_switch)
-                word |= bit_masks[h_bit] << (word_weight - h_bit);
-                *cp++ = word;
-                /* "output" row(s) */
-                for (i = pkrepcount * bytes_wide /
+	      if (count < word_weight && count < h_bit) {
+	      	h_bit -= count;
+	       	word_weight -= count;
+	       	if (paint_switch)
+        	  word |= bit_masks[count] << word_weight;
+		  count = 0;
+	      }
+	      else if (count >= h_bit && h_bit <= word_weight) {
+		if (paint_switch)
+		word |= bit_masks[h_bit] << (word_weight - h_bit);
+		*cp++ = word;
+		/* "output" row(s) */
+		for (i = pkrepcount * bytes_wide /
                            BYTES_PER_BMUNIT; i > 0; --i) {
-                  *cp = *SUB(cp, bytes_wide);
-                   ++cp;
-                }
-                rows_left -= pkrepcount + 1;
-                pkrepcount = 0;
-                word = 0;
-                word_weight = BITS_PER_BMUNIT;
-                count -= h_bit;
-                h_bit = thechar->bmp.w;
-              } else {
-                if (paint_switch) word |= bit_masks[word_weight];
-                  *cp++ = word;
-                word = 0;
-                count -= word_weight;
-                h_bit -= word_weight;
-                word_weight = BITS_PER_BMUNIT;
-                }
-              }
-              paint_switch = 1 - paint_switch;
-            }
-            if (cp != (BMUNIT*)
+		  *cp = *SUB(cp, bytes_wide);
+		   ++cp;
+		}
+		rows_left -= pkrepcount + 1;
+		pkrepcount = 0;
+		word = 0;
+		word_weight = BITS_PER_BMUNIT;
+		count -= h_bit;
+		h_bit = thechar->bmp.w;
+	      } else {
+		if (paint_switch) word |= bit_masks[word_weight];
+	 	  *cp++ = word;
+		word = 0;
+		count -= word_weight;
+	        h_bit -= word_weight;
+		word_weight = BITS_PER_BMUNIT;
+	        }
+	      }
+	      paint_switch = 1 - paint_switch;
+	    }
+	    if (cp != (BMUNIT*)
              ((uchar*) thechar->bmp.bits + bytes_wide * thechar->bmp.h)){
-              pfprot("Wrong number of bits stored:  char. %d, font %s",
+       	      pfprot("Wrong number of bits stored:  char. %d, font %s",
                       thechar->ch,pkfilen);
               exit(1);
             }
-            if (rows_left != 0 || h_bit != thechar->bmp.w) {
-              pfprot("Bad PKfile (%s), too many bits", 
+	    if (rows_left != 0 || h_bit != thechar->bmp.w) {
+	      pfprot("Bad PKfile (%s), too many bits", 
                        pkfilen);
               exit(1);
             }
-        }
+	}
         pkclose();
         /* print_bitmap(&thechar->bmp); */
 #ifdef DEBUGPK
-        pfprot("... pkloadchar)");
+	pfprot("... pkloadchar)");
 #endif
 }
 
@@ -563,12 +564,10 @@ void pkshrinkcharbw(chdesc* theChar) {
   theChar->bmp2.h=shrunkh=theChar->vof2 +
     ROUNDUP(theChar->bmp.h-cols,ishrink) +1;
   theChar->bmp2.type=BLACKNWHITE;
-  locklrumem(&theChar->bmp.bits);
   alloc_bitmapbw(&theChar->bmp2);
-  unlocklrumem(&theChar->bmp.bits);
   oldp=theChar->bmp.bits;
   if(oldp==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n")
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
   newp=theChar->bmp2.bits;
@@ -578,7 +577,7 @@ void pkshrinkcharbw(chdesc* theChar) {
   while(rowsleft) {
     if(rows>rowsleft) rows=rowsleft;
     colsleft=theChar->bmp.w;
-    m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));
+    m=(1 << (BITS_PER_BMUNIT -1));
     cp=newp;
     cols=initcols;
     while(colsleft){
@@ -586,7 +585,7 @@ void pkshrinkcharbw(chdesc* theChar) {
       if(sample(oldp,theChar->bmp.bmu_wide,theChar->bmp.w-colsleft,
                 cols,rows)>=blevel) *cp|=m;
       if(m==1) {
-        m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));
+        m=(1 << (BITS_PER_BMUNIT -1));
         ++cp;
       } else m >>=1;
       colsleft-=cols;
@@ -613,7 +612,7 @@ void pkshrinkchargs(chdesc* theChar) {
   register BMUNIT m,*cp;
 
 #ifdef DEBUGPK
-        pfprot("(pkshrinkchargs: fontdatptr %d char %d ...",
+	pfprot("(pkshrinkchargs: fontdatptr %d char %d ...",
            theChar->fontdataptr,theChar->ch); 
 #endif
 
@@ -638,12 +637,10 @@ void pkshrinkchargs(chdesc* theChar) {
   theChar->bmp2.h=shrunkh=theChar->vof2 +
     ROUNDUP(theChar->bmp.h-cols,ishrink) +1;
   theChar->bmp2.type=GREYSCALE;
-  locklrumem(&theChar->bmp.bits);
   alloc_bitmapgs(&theChar->bmp2);
-  unlocklrumem(&theChar->bmp.bits);
   oldp=theChar->bmp.bits;
   if(oldp==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n");
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
   newp=theChar->bmp2.bits;
@@ -661,7 +658,7 @@ void pkshrinkchargs(chdesc* theChar) {
     while(colsleft){
       if(cols>colsleft) cols=colsleft;
       *cp |= 
-         ((BMUNIT)greytab[(sample(oldp,theChar->bmp.w-colsleft, cols,rows))])  << m; 
+         greytab[(sample(oldp,theChar->bmp.w-colsleft, cols,rows))]  << m; 
       if(m) m-=GREYSCALE;
       else {
         m=BITS_PER_BMUNIT -colors;
@@ -700,7 +697,7 @@ void pkshrinkchargs(chdesc* theChar) {
   /*print_bitmap(&(theChar->bmp)); */ 
   /*print_bitmap(&(theChar->bmp2)); */
 #ifdef DEBUGPK
-        pfprot("... pkshrinkchargs)"); 
+	pfprot("... pkshrinkchargs)"); 
 #endif
 }
 
@@ -710,7 +707,7 @@ void pkshrinkcharazgs(chdesc* theChar) {
   
   int destbmuw, srcbmuw, j,i;
   int rows,cols,firstcols,firstrows,srcrow,srccol,sam;
-  int mrows,mcols;
+  int mrows,mcols,ishrink;
   BMUNIT m;
   BMUNIT *cp,*destptr,*srcptr;
 
@@ -727,6 +724,7 @@ void pkshrinkcharazgs(chdesc* theChar) {
 
   freelrumem(&(theChar->bmp2.bits));
   touchlrumem(&(theChar->bmp.bits));
+  /* ishrink=CEIL(fshrink); fixed size commented out. see below */
   theChar->shrink=fshrink; 
  
   
@@ -754,14 +752,12 @@ void pkshrinkcharazgs(chdesc* theChar) {
   if(firstrows<=0 || firstcols<=0)   
      pfprot("IMPORTANT DEBUGINFORMATION 
 break with fro %d fco %d
-fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
-       fshrink,theChar->hof,theChar->vof,theChar->hof2,theChar->vof2);
+fshr %f ishr %d hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
+       fshrink, ishrink,theChar->hof,theChar->vof,theChar->hof2,theChar->vof2);
   
        
   theChar->bmp2.type=GREYSCALE;
-  locklrumem(&theChar->bmp.bits); 
   alloc_bitmapgs(&theChar->bmp2);
-  unlocklrumem(&theChar->bmp.bits); 
   destptr=theChar->bmp2.bits;
   destbmuw=theChar->bmp2.bmu_wide;
   memset(destptr,0,BYTES_PER_BMUNIT*destbmuw*theChar->bmp2.h);
@@ -771,7 +767,7 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
   SETBMUW(srcbmuw);
 
   if(srcptr==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n");
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
 
@@ -810,6 +806,9 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
         ++cp;
       };
       j++;
+      /*srccol=ROUND(j*fshrink)+theChar->hof; 
+      cols=MIN(ishrink,theChar->bmp.w-srccol); */
+
       srccol+=cols; 
       mcols=ROUND((j+1)*fshrink)-ROUND(j*fshrink);
       cols=MIN(mcols,theChar->bmp.w-srccol); 
@@ -817,9 +816,13 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
     /* pfprot("did row\n");*/
     i--; 
     destptr+=destbmuw; 
+    /* srcrow= (theChar->vof+1)-ROUND(i*fshrink);
+    rows=MIN(ishrink,theChar->bmp.h-srcrow); */
+    
     srcrow+=rows;
     mrows=ROUND(i*fshrink)-ROUND((i-1)*fshrink);
     rows=MIN(mrows,theChar->bmp.h-srcrow); 
+   
     srcptr=theChar->bmp.bits+srcrow*srcbmuw;
   }
 /* #else     that is ifdef GREYINBMU */
@@ -863,9 +866,7 @@ void pkshrinkcharazprecgs(chdesc* theChar) {
   theChar->bmp2.h = CEIL(theChar->bmp.h / fshrink) +2;      
        
   theChar->bmp2.type=GREYSCALE;
-  locklrumem(&theChar->bmp.bits); 
   alloc_bitmapgs(&theChar->bmp2);
-  unlocklrumem(&theChar->bmp.bits); 
   destptr=theChar->bmp2.bits;
   destbmuw=theChar->bmp2.bmu_wide;
   memset(destptr,0,BYTES_PER_BMUNIT*destbmuw*theChar->bmp2.h);
@@ -873,7 +874,7 @@ void pkshrinkcharazprecgs(chdesc* theChar) {
   SETBMUW(srcbmuw);
 
   if(theChar->bmp.bits==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n");
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
   
@@ -920,19 +921,18 @@ fr %f tw %f bw %f oy %d oh %d iy %d ih %d\n",
       iw=MAX(0,MIN(FLOOR(fj+fcols)-CEIL(fj),theChar->bmp.w-ix));
   
       /*pfprot("   col info at fj %f
-        fc %f ox %d ow %d ix %d iw %d\n",fj,fcols,ox,ow,ix,iw);*/ 
+	fc %f ox %d ow %d ix %d iw %d\n",fj,fcols,ox,ow,ix,iw);*/ 
     
       leftweight=1-(fj-FLOOR(fj));
       rightweight=1-(CEIL(fj+fcols)-fj-fcols);
 
       fsam=0;
       /* count inner part */
-      if(iw!=0 && ih!=0){
+      if(iw!=0 && ih!=0)
         if(iw==1 && ih==1)
           fsam+=TESTBIT(srcptriy,ix);
         else
           fsam+=sample(srcptriy, ix, iw,ih);
-      }
       /* count top and bottom row */
       if(iy==oy+1 && iw!=0)
         fsam+=topweight*samplerow(srcptroy,ix, iw);
@@ -1049,9 +1049,7 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
   theChar->bmp2.h = CEIL(theChar->bmp.h / fshrink) +2;
                 
   theChar->bmp2.type=BLACKNWHITE;
-  locklrumem(&theChar->bmp.bits); 
   alloc_bitmapgs(&theChar->bmp2);
-  unlocklrumem(&theChar->bmp.bits); 
   destptr=theChar->bmp2.bits;
   destbmuw=theChar->bmp2.bmu_wide;
   memset(destptr,0,BYTES_PER_BMUNIT*destbmuw*theChar->bmp2.h);
@@ -1060,8 +1058,9 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
   srcbmuw=theChar->bmp.bmu_wide;
   SETBMUW(srcbmuw);
 
+
   if(srcptr==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n");
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
 
@@ -1071,7 +1070,7 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
   mrows=MAX(1,ROUND(i*fshrink)-ROUND((i-1)*fshrink));
   while(rows>0) {
           
-    m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));  
+    m=(1 << (BITS_PER_BMUNIT -1));  
     cp=destptr;
     srccol=0;
     cols=firstcols;
@@ -1132,19 +1131,17 @@ void cheapshrinkgs(bitmap* bmp, bitmap* bmp2){
 
   int rowsleft, colsleft, sum;
   int newbuw, oldbuw, m, rshift, lshift;
-  BMUNIT  *oldp, *newp, *dp, *sp, *op;
+  BMUNIT  *oldp, *newp, *op, *dp, *sp;
   uchar tabgs[GSGREY*GSGREY+1];
 
 #ifdef DEBUGPK
   pfprot("( cheapshrinkgs fontdatptr...)");
 #endif
 
-  locklrumem(&bmp->bits); 
   alloc_bitmapgs(bmp2);
-  unlocklrumem(&bmp->bits); 
   oldp=bmp->bits;
   if(oldp==NULL) {
-    pfprot("\nfatal error: memory management, cannot happen? sorry\n");
+    pfprot("\nfatal error: my ugly memory management. sorry\n");
     exit(1);
   }
   if(bmp2->w*GSGREY != bmp->w || bmp2->h*GSGREY != bmp->h){
@@ -1167,19 +1164,18 @@ void cheapshrinkgs(bitmap* bmp, bitmap* bmp2){
     lshift=BITS_PER_BMUNIT-GREYSCALE;
     rshift=BITS_PER_BMUNIT-GSGREY;
     while(colsleft){
-      op=sp;
 #if GSGREY==2
-      sum= bit_count[(((*op)>>rshift) & ((1L<<GSGREY)-1L))] 
-        +bit_count[(((op[oldbuw])>>rshift) & ((1L<<GSGREY)-1L))];
+    sum= bit_count[(((*sp)>>rshift) & ((1L<<GSGREY)-1L))] 
+        +bit_count[(((sp[oldbuw])>>rshift) & ((1L<<GSGREY)-1L))];
 #endif
 #if GSGREY==4
-      sum=bit_count[((*(op)>>rshift)&((1L<<GSGREY)-1L))] 
-        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
-        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
-        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))];
+    sum=bit_count[((*(op=sp)>>rshift)&((1L<<GSGREY)-1L))] 
+       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
+       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
+       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))];
 #endif
 /*pfprot("%d:%d*",sum,tabgs[sum]);*/
-      *dp |= (((BMUNIT)tabgs[sum])  << lshift); 
+      *dp |= (tabgs[sum]  << lshift); 
       if(lshift) lshift-=GREYSCALE;
       else {
         lshift=BITS_PER_BMUNIT-GREYSCALE;
