@@ -268,44 +268,7 @@ char encodingAdobe[256][5]={
    /* f8 */ "l",  "o",  "oe",  "\"s",  "",  "",  "",  "",
 };
 
-char encodingTeXBase1[256][5]={
-   /* 00 */ "",  "\"",  "fi",  "fl",  "",  "\"",  "L",  "l",
-   /* 08 */ "",  "\"",  "",  "\"",  "",  "",  "Z",  "z",
-   /* 10 */ "\"",  "i",  "",  "",  "",  "",  "",  "",
-   /* 18 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* 20 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* 28 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* 30 */ "0",  "1",  "2",  "3",  "4",  "5",  "6",  "7",
-   /* 38 */ "8",  "9",  "",  "",  "",  "",  "",  "",
-   /* 40 */ "",  "A",  "B",  "C",  "D",  "E",  "F",  "G",
-   /* 48 */ "H",  "I",  "J",  "K",  "L",  "M",  "N",  "O",
-   /* 50 */ "P",  "Q",  "R",  "S",  "T",  "U",  "V",  "W",
-   /* 58 */ "X",  "Y",  "Z",  "",  "",  "",  "",  "",
-   /* 60 */ "",  "a",  "b",  "c",  "d",  "e",  "f",  "g",
-   /* 68 */ "h",  "i",  "j",  "k",  "l",  "m",  "n",  "o",
-   /* 70 */ "p",  "q",  "r",  "s",  "t",  "u",  "v",  "w",
-   /* 78 */ "x",  "y",  "z",  "",  "",  "",  "",  "",
-   /* 80 */ "",  "",  "",  "f",  "",  "",  "",  "",
-   /* 88 */ "\"",  "",  "S",  "",  "OE",  "",  "",  "",
-   /* 90 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* 98 */ "\"",  "",  "s",  "",  "oe",  "",  "",  "Y",
-   /* a0 */ "",  "",  "c",  "L",  "",  "Y",  "",  "",
-   /* a8 */ "",  "",  "",  "",  "",  "",  "",  "\"",
-   /* b0 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* b8 */ "",  "",  "",  "",  "",  "",  "",  "",
-   /* c0 */ "\"A",  "\"A",  "\"A",  "\"A",  "\"A",  "\"A",  "AE",  "C",
-   /* c8 */ "\"E",  "\"E",  "\"E",  "\"E",  "\"I",  "\"I",  "\"I",  "\"I",
-   /* d0 */ "D",  "\"N",  "\"O",  "\"O",  "\"O",  "\"O",  "\"O",  "x",
-   /* d8 */ "O",  "\"U",  "\"U",  "\"U",  "\"U",  "\"Y",  "p",  "\"s",
-   /* e0 */ "\"a",  "\"a",  "\"a",  "\"a",  "\"a",  "\"a",  "ae",  "c",
-   /* e8 */ "\"E",  "\"E",  "\"E",  "\"E",  "\"I",  "\"I",  "\"I",  "\"I",
-   /* f0 */ "d",  "\"n",  "\"o",  "\"o",  "\"o",  "\"o",  "\"o",  "",
-   /* f8 */ "o",  "\"u",  "\"u",  "\"u",  "\"u",  "\"y",  "p",  "\"y",
-
-};
-
-
-#define NUMBEROFENCODINGS 9
+#define NUMBEROFENCODINGS 8
 
 char* encodingnames[]={
   "TeX text",
@@ -316,7 +279,6 @@ char* encodingnames[]={
   "Extended TeX Font Encoding",
   "dc.vec",
   "Adobe StandardEncoding",
-  "TeXBase1Encoding",
 };
 
 void* encodings[]={
@@ -328,7 +290,6 @@ void* encodings[]={
   encodingDC,
   encodingDC,
   encodingAdobe,
-  encodingTeXBase1,
 };   
 
 
@@ -345,16 +306,16 @@ static long fofint(uchar b)  {  uchar i;  long n;
 int tfmfind(char *ffpath,char *fontname,char *fftotal) {  
   char ffname[MAXPATHSTR];
   int foundfile;
-  char *kpsename=NULL;
 
 #ifdef KPATHSEA
-  kpsename=kpse_find_tfm(fontname);
-  foundfile = (kpsename!=NULL);
-  if(kpsename){
-    strncpy(fftotal, kpsename,MAXPATHSTR-1);
-    fftotal[MAXPATHSTR-1]=0;
-    freemem(&kpsename);         
-  }       
+  char *name=NULL;
+
+  name = kpse_find_tfm(fontname);
+  foundfile = (name!=NULL);
+  if(name){
+    strcpy(fftotal, name);
+    freemem(&name);
+  }         
 #else
   sprintf(ffname, "%s.tfm", fontname);
   foundfile = msearch(ffpath,ffname,fftotal);
@@ -373,11 +334,13 @@ int tfmfind(char *ffpath,char *fontname,char *fftotal) {
 int tfmdef(char *fftotal,int fdb,long chksum) {  
   short ll, lh, bc, ec, nw, nh, nd, i,j;
   uchar b1, b2, b3;  short FORLIM;
+  fontdesc *font;
   char encstr[41];
   float designsize;
   long dummy[256];
   long fofchk;
   fofile = fopen(fftotal, "rb");
+  font=fontdatabase+fdb;
   if (fofile==0)   return(0);  /*this cant happen */
   ll = fofint(2);  
   lh = fofint(2);  
@@ -392,12 +355,7 @@ int tfmdef(char *fftotal,int fdb,long chksum) {
     fclose(fofile);  
     return(0);
   }
-  if(FD(fdb)->mch < ec) FD(fdb)->mch = ec;
-  if (ec>=MAXCHARS) {
-    pfprot(" - to many chars ");  
-    fclose(fofile);  
-    return(0);
-  }
+  if(font->mch < ec) font->mch = ec;
   fseek(fofile, 24L, 0);  
   fofchk = fofint(4);
   if (chksum != 0) if (fofchk != 0) if (chksum != fofchk)
@@ -411,29 +369,29 @@ int tfmdef(char *fftotal,int fdb,long chksum) {
   pfverb(" - encoding: %s ",encstr); 
   for(i=0;i<NUMBEROFENCODINGS; i++) 
     if(STRCASECMP(encodingnames[i],encstr)==0)
-      FD(fdb)->encoding=encodings[i]; 
-  if(FD(fdb)->encoding) 
+      font->encoding=encodings[i]; 
+  if(font->encoding) 
     pfverb(": known ");
   else {   
     for(i=0;i<NUMBEROFENCODINGS; i++) 
       if(STRNCASECMP(encodingnames[i],encstr,strlen(encodingnames[i]))==0)
-        FD(fdb)->encoding=encodings[i], j=i; 
-    if(FD(fdb)->encoding) 
+        font->encoding=encodings[i], j=i; 
+    if(font->encoding) 
       pfverb(": assuming %s ",encodingnames[j]);
   }   
   fseek(fofile, (lh + ec - bc + 7L) * 4, 0);
   FORLIM = nw + nh + nd;
   for (i = 0; i < FORLIM; i++)
-    dummy[i] = scaled(fofint(4), FD(fdb)->foscf);
+    dummy[i] = scaled(fofint(4), font->foscf);
   fseek(fofile, lh * 4L + 24, 0);
   for (i = bc; i <= ec; i++) {
     b1 = fofbyte();  b2 = fofbyte();  fofbyte();  fofbyte();
-    FD(fdb)->chv[i].fontdataptr=fdb;
-    FD(fdb)->chv[i].ch=i;
-    FD(fdb)->chv[i].tfmtfw = dummy[b1];
-    FD(fdb)->chv[i].tfmtfh = dummy[nw + (b2 >> 4)];
-    FD(fdb)->chv[i].tfmtfd = dummy[nw + nh + (b2 & 15)];
-    FD(fdb)->chv[i].fty |= TFMTYPE;  
+    font->chv[i].fontdataptr=fdb;
+    font->chv[i].ch=i;
+    font->chv[i].tfmtfw = dummy[b1];
+    font->chv[i].tfmtfh = dummy[nw + (b2 >> 4)];
+    font->chv[i].tfmtfd = dummy[nw + nh + (b2 & 15)];
+    font->chv[i].fty |= TFMTYPE;  
   }
   fclose(fofile);  
   pfverb(" - TFMfile ok ");
