@@ -6,7 +6,7 @@
 
 int vffind(char*, char*, char*);
 int vfdef(char*,int,long,long);
-void vflookuppk(int);
+int vflookuppk(int,long);
 
 
 
