@@ -19,8 +19,7 @@
 
 
 
-/* #define DEBUGMEM */    
-/* #define DEBUGMEMUSAGE */
+/* #define DEBUGMEM     */
 /* #define DEBUGKILLLRU */
 /* #define DEBUGBITMAPS */
 /* #define DEBUGFILE */
@@ -55,9 +54,9 @@ long scaled(long w, long z) {  long s; ulong t=w, u=z;
 }
 
 
-/*******************************************************/
-/*  one day here will be a kind of memorymenagement !  */
-/*                                                     */
+
+/*  one day here will be a kind of memorymenagement !*/
+
 
 #define MEM(ap)   (*((char**)(ap)))
 
@@ -65,30 +64,8 @@ long scaled(long w, long z) {  long s; ulong t=w, u=z;
 #define NEXT(ap)   (((char**)(ap))+1)
 #define PREV(ap)   (((char**)(ap))+2)
 #define SIZE(ap)   (long*)(((char**)(ap))+3)
-#define LOCK(ap)   (char*)(((char**)(ap))+4)
-#define USER(ap)  (char*)(((char**)(ap))+5)
-
-#define BASE(up)  (char*)(((char**)(up))-5)
-
-/*
-within memory it looks as follows:
-
-char*** REF   pointer to the users pointer to his memory 
-char**  NEXT  pointer to next lrumem-element
-char**  PREV  pointer to previous lrumem-element
-long    SIZE  size of this element
-char    LOCK  lock flag to disable killing
-char    users data, here points the users pointer to    
-char    even more users data
-char    and so on ....
-
-The user has exactly one pointer to his data and operates
-on it as usual. From our point of view, we have a linked
-list of memory areas. The users data is preceeded by our data.
-As we keep a reference on the users only pointer, we will
-set this to NULL if we kill his data. Thus, he will know.
-*/
-
+#define USER(ap)  (char*)(((char**)(ap))+4)
+#define BASE(ap)  (char*)(((char**)(ap))-4)
 
 
 static char* firstlru=NULL;
@@ -107,11 +84,11 @@ void printlrumem(void) {
       pfprot("*** LINK ERROR ***\n");
     if(iptr==lastlru && *NEXT(iptr) != NULL)
       pfprot("*** LINK ERROR ***\n");
-    if(**REF(iptr)!=iptr+20) /* test fails ==> seg fault BEFOR warning :-( */ 
+    if(**REF(iptr)!=iptr+16) /* test fails ==> seg fault BEFOR warning :-( */ 
       pfprot("*** REF ERROR ***\n");
     count++;
-    pfprot("mem at 0x%x *rev 0x%x size %d lock %d prev 0x%x next 0x%x \n",
-           iptr,**REF(iptr),*SIZE(iptr),*LOCK(iptr),*PREV(iptr),*NEXT(iptr));
+    pfprot("mem at 0x%x *rev 0x%x size %d prev 0x%x next 0x%x \n",
+           iptr,**REF(iptr),*SIZE(iptr),*PREV(iptr),*NEXT(iptr));
     before=iptr;
     iptr=*NEXT(iptr);
     if(iptr!=NULL)
@@ -122,92 +99,76 @@ void printlrumem(void) {
 }
 
 void Tptr(char* ap) {  
-  if(ap==NULL) {pfprot(" - not enough memory :-( \n"); exit(1);}
-}
-
-void Tptrlru(char* ap) {  
-  if(ap==NULL) {pfprot("\n\n - run out of LRU memory: adjust \"lrum\" in the startup-file? \n"); exit(1);}
+  if(ap==NULL) {pfprot(" - not enough memory :-( "); exit(1);}
 }
 
 int killlru(void){
-  char* killit;
-  char** ptme1;
-  char** ptme2;
+  char* bup;
   if(firstlru==NULL) return(0);
 #ifdef DEBUGKILLLRU
   pfprot("(mem: killlru)");
   printlrumem();  
 #endif
 #ifdef DEBUGMEM
-  pfprot("(mem: killlru 0x%x?)",firstlru+20);
+  pfprot("(mem: killlru 0x%x)",firstlru+16);
 #endif
-  killit=firstlru;
-  while(*LOCK(killit)==1 && *NEXT(killit)!=NULL) 
-    killit= *(NEXT(killit)); 
-  if(*LOCK(killit)==1)   return(0);
-  ptme1=PREV(killit);
-  ptme2=NEXT(killit);
-  if(firstlru==lastlru) {
-    firstlru=NULL;
-    lastlru=NULL;
-  } else {
-    if(*ptme1!=NULL) *NEXT(*ptme1)=*ptme2; else firstlru=*ptme2; 
-    if(*ptme2!=NULL) *PREV(*ptme2)=*ptme1; else lastlru=*ptme1;
-  }
-  **REF(killit)=NULL;
-  totallrumem-=*SIZE(killit);
-  free(killit);
+  bup=*NEXT(firstlru);
+  totallrumem-=*SIZE(firstlru);
+  **REF(firstlru)=NULL;
+  free(firstlru);
+  firstlru=bup;
+  if(firstlru!=NULL)   /* Danke Robo! */
+    *PREV(firstlru)=NULL;
 #ifdef DEBUGKILLLRU
   printlrumem();
 #endif  
   return(1);
 }
 
-void locklrumem(void* ap) { 
-  Tptrlru(MEM(ap));
-  touchlrumem(ap);
-  *LOCK(BASE(MEM(ap)))=1;
+void addlru(char** ap, long size){
+  if(firstlru!= NULL) {
+    *NEXT(lastlru)=MEM(ap);
+    *PREV(MEM(ap))=lastlru;
+    *NEXT(MEM(ap))=NULL;
+  } else {
+    *PREV(MEM(ap))=NULL;
+    *NEXT(MEM(ap))=NULL;
+    firstlru=MEM(ap);
+  }
+  lastlru=MEM(ap);
+  *SIZE(MEM(ap))=size;
+  totallrumem+=size;
+  *(REF(MEM(ap)))=ap;
+  MEM(ap)=USER(MEM(ap));
 }
 
-void unlocklrumem(void* ap) {
-  if(MEM(ap)==NULL) return; /* no error here */ 
-  touchlrumem(ap);
-  *LOCK(BASE(MEM(ap)))=0;
+/* 
+adjust ref, if pointer to lrumen is relocated .g. by realloc(lru!)mem 
+didn't test it: prefer pointers not to be reallocated ...  
+*/
+/*  
+void setreflru(void* ap){
+  *(BASE(MEM(ap)))=ap;
 }
-
+*/  
   
 void alloclrumem(void* ap,long size) { 
   char* res;
-  char* me;
 #ifdef DEBUGMEM
-  pfprot("(mem: alloclru 0x%x %d at ...",MEM(ap),size);
+  pfprot("(mem: alloc 0x%x %d at ...",MEM(ap),size);
 #endif
   size=MAX(1,size);
-  while(totallrumem+size>maxlrumem) 
-    if(!killlru()) Tptrlru(NULL);
-  res = malloc(size+5*sizeof(char*)); 
-  Tptrlru(res);
-  me=res;
-  if(firstlru!= NULL) {
-    *NEXT(lastlru)=me;
-    *PREV(me)=lastlru;
-  } else {
-    *PREV(me)=NULL;
-    firstlru=me;
-  }
-  lastlru=me;
-  *REF(me)=ap;
-  *NEXT(me)=NULL;
-  *SIZE(me)=size;
-  *LOCK(me)=0;
-  MEM(ap)=USER(me);
-  totallrumem+=size;
-#ifdef DEBUGMEMUSAGE
-  pfprot("(%.1fk)",totallrumem/1024.);
-#endif
+  while(totallrumem+size>MAXLRUPOOL) 
+    if(!killlru()) Tptr(NULL);
+  do
+    if((res = malloc(size+4*sizeof(char*))) != NULL) break;  
+  while(killlru());
+  Tptr(res);
+  MEM(ap)=res;
 #ifdef DEBUGMEM
-  pfprot("... 0x%x)",USER(me));
+  pfprot("... 0x%x)",USER(MEM(ap)));
 #endif
+  addlru(ap,size);
 }
 
 void realloclrumem(void* ap, long size) { 
@@ -220,27 +181,23 @@ void realloclrumem(void* ap, long size) {
 #ifdef DEBUGMEM
   pfprot("(mem: realloclru 0x%x %d at ...",MEM(ap),size);
 #endif
-  if(MEM(ap)==NULL) {alloclrumem(ap,size);return;}
   size=MAX(1,size);
-  oldsize=*SIZE(BASE(MEM(ap))); 
-  while(totallrumem+size-oldsize>maxlrumem) 
-    if(!killlru()) Tptrlru(NULL);
-  Tptrlru(MEM(ap)); /* killed itself */
-  me=BASE(MEM(ap));  
-  res=realloc(me,size+5*sizeof(char*));
-  Tptrlru(res);
-  me=res;
+  if(MEM(ap)==NULL) alloclrumem(ap,size);
+  me=BASE(MEM(ap));
   ptme1=PREV(me);
   ptme2=NEXT(me);
-  if(*ptme1!=NULL) *NEXT(*ptme1)=me; else firstlru=me;
-  if(*ptme2!=NULL) *PREV(*ptme2)=me; else lastlru=me;
-  *SIZE(me)=size;
-  MEM(ap)=USER(me);  
+  oldsize=*SIZE(me);
+  while(totallrumem+size-oldsize>MAXLRUPOOL) 
+    if(!killlru()) Tptr(NULL);
+  do
+    if((res = realloc(me,size+4*sizeof(char*))) != NULL) break;  
+  while(killlru());
+  Tptr(res);
+  if(*ptme1!=NULL) *NEXT(*ptme1)=res; else firstlru=res;
+  if(*ptme2!=NULL) *PREV(*ptme2)=res; else lastlru=res;
+  *SIZE(res)=size;
   totallrumem+=size-oldsize;
-  /* could do a touch */
-#ifdef DEBUGMEMUSAGE
-  pfprot("(%.1fk)",totallrumem/1024.);
-#endif
+  MEM(ap)=USER(res);  
 #ifdef DEBUGMEM
   pfprot("... 0x%x)",MEM(ap));
 #endif
@@ -268,9 +225,6 @@ void freelrumem(void* ap) {
   }
   free(me);
   MEM(ap)=NULL;
-#ifdef DEBUGMEMUSAGE
-  pfprot("(%.1fk)",totallrumem/1024.);
-#endif
 }
  
 void touchlrumem(void* ap) {
@@ -280,7 +234,6 @@ void touchlrumem(void* ap) {
 #ifdef DEBUGMEM
   pfprot("(mem: touchlru 0x%x)",MEM(ap));
 #endif
-  Tptrlru(MEM(ap));
   if(firstlru==lastlru) return;
   me=BASE(MEM(ap));
   if(me==lastlru) return;
@@ -300,30 +253,32 @@ void touchlrumem(void* ap) {
 #endif
 }  
 
-/* in an early version we considered to free lrumem here ... */
-/* which was a quite sick idea. So we do not do it anymore.  */
 void allocmem(void* ap,long anz) { 
   char* res;
 #ifdef DEBUGMEM
   pfprot("(mem: alloc 0x%x %d at ...",MEM(ap),anz);
 #endif
   anz=MAX(1,anz);
-  res = malloc(anz);
+  do {
+    if((res = malloc(anz)) != NULL) break;  
+  } while(killlru());
 #ifdef DEBUGMEM
-  pfprot("(alloc at 0x%x)",res);
+  pfprot("... 0x%x)",res);
 #endif
   Tptr(res);
   MEM(ap)=res; 
 }
 
-void reallocmem(void *ap, long anz) { 
+reallocmem(void *ap, long anz) { 
   char* res;
 #ifdef DEBUGMEM
   pfprot("(mem: realloc 0x%x %d)",MEM(ap),anz);
 #endif
   anz=MAX(1,anz);
-  if(MEM(ap)==NULL) res=malloc(anz);
-  else res = realloc(MEM(ap),anz);  
+  if(MEM(ap)==NULL) allocmem(ap,anz);
+  do
+    if((res = realloc(MEM(ap),anz)) != NULL) break;  
+  while(killlru());
   Tptr(res);
   MEM(ap)=res;  
 }
@@ -354,9 +309,9 @@ char *stralloccpy(char** dest, char* src)
 
 /* recursive directory searching ... 
 
-   ... and they're telling everyone that I, Thomas Moor, dont know too much
+   ... and theyre telling everyone that i, thomas moor, dont know too much
    about exaiming directories. And they are the reason of the very slow
-   starting up. Workaround: name the directories to be scanned explicitetly,
+   starting up. Workaround: name the directories to be scanned explicietly,
    first, separeted by colons, followed by those, which are eventually to be
    scanned recursivly. 
    
@@ -372,6 +327,7 @@ char *stralloccpy(char** dest, char* src)
 #ifndef DOSFILES
 
 int checkapath(char* prepath,char* path) {
+  char nprepath[MAXPATHSTR], npath[MAXPATHSTR];
   int i,sep,pn,ppn;
 
   /* fprintf(prot,"\n chkapath %s =?= %s \n",prepath,path); */
@@ -411,8 +367,6 @@ int checkapath(char* prepath,char* path) {
       return(checkapath(prepath,path+i));
     return(0);
   }
-  pfprot("(checkapath: never reach this end!)");
-  return(1);
 }
 
 
@@ -465,10 +419,11 @@ int chkrshis(char* result,char* prepath, char* name) {
 }
 
 int rsearch(char* done,char* path,int dep) {
+  char ndone[MAXPATHSTR], npath[MAXPATHSTR];
   FILE* testfile;
   DIR *thisdir, *testdir;
   struct dirent *thisentry;
-  int i,dn,sep;
+  int i,dn,sep,ndep,links;
   struct stat stats;
   
   /* set sep to the position of next "//" in path or -1 if no such */
@@ -494,7 +449,7 @@ int rsearch(char* done,char* path,int dep) {
     return(0);
   }
  
-  /* more recursive, but with some non-recursive dirs before */
+  /* more recursive, but with some non-recursive dirs befor */
   if(sep > 0) {
     strncat(done,path,sep);
     return(rsearch(done,path+sep,0));
@@ -512,7 +467,7 @@ int rsearch(char* done,char* path,int dep) {
       if(rsearch(done,path+1,dep))  return(1);
       done[dn]=0;
       if ((thisdir=opendir(done))==NULL) return(0);
-      while((thisentry=readdir(thisdir)))
+      while(thisentry=readdir(thisdir))
         if(    (strcmp(thisentry->d_name,".") != 0)
            && (strcmp(thisentry->d_name,"..") != 0)
            && (strlen(thisentry->d_name)+dn+2 < MAXPATHSTR) ){   
@@ -538,6 +493,7 @@ int msearch(char* mpath,char* filename,char* result) {
   int mpnpo, pnpo,hopo, found;
   char pn[MAXPATHSTR];
   char* homedir;
+  char ch;
  
   homedir = getenv("HOME");
   if(homedir == NULL) homedir="/home_not_def";
@@ -576,6 +532,7 @@ int msearch(char* mpath,char* filename,char* result) {
 
 int completefile(char* total, int which) {
   char npath[MAXPATHSTR], name[MAXPATHSTR];
+  FILE* testfile;
   DIR *thisdir, *testdir;
   struct dirent *thisentry;
   int plen,nlen,tlen;
@@ -618,7 +575,7 @@ int completefile(char* total, int which) {
   
   if((thisdir=opendir(npath))==NULL) return(0);
   found=0;
-  while((thisentry=readdir(thisdir)))
+  while(thisentry=readdir(thisdir))
     if(    (strncmp(thisentry->d_name,name,nlen) ==0)
         && (strlen(thisentry->d_name)+plen+2 < MAXPATHSTR) ){ 
       found++;   
@@ -646,23 +603,25 @@ int completefile(char* total, int which) {
 }
 
 void setworkdir(void) {
-#ifndef GNU_GETCWD
-  /* dirty hack, since getcwd is not allways gnu-c ... */
   char* buptr;
+  
+  /* correct version: linux or gnu-c resp. ... */
+#ifdef GNU_GETCWD
+  workdir=getcwd(NULL, 0);
+  if(workdir==NULL) {pfprot("\nfatal error: memory .. getcwd ??\n");exit(1);}
+#else  
+  /* dirty hack, since getcwd is not allways gnu-ic ... */
   allocmem(&buptr,2048);
   buptr=getcwd(buptr, 2047);
   buptr[2047]=0;  /*Bug removed by Richard Vosse, Thanks!*/
   workdir=NULL;
   stralloccpy(&workdir, buptr);
   freemem(&buptr);
-#else
-  /* correct version: linux or gnu-c resp. ... */
-  workdir=getcwd(NULL, 0);
-  if(workdir==NULL) {pfprot("\nfatal error: memory .. getcwd ??\n");exit(1);} 
 #endif  
 }
 
 int dvistandard(char** dst,char* src) {  /* may be src==filename */
+  uchar o;
   char rbu[4];
   FILE* file;
   char s[MAXPATHSTR+1];
@@ -707,18 +666,14 @@ int dvistandard(char** dst,char* src) {  /* may be src==filename */
   for(i=0;i<slen-3;){
     lastsep=0;
     for(i=0;i<slen-3;i++) {
-      if(    ss[i]==DIRSEPCHAR 
-          && ss[i+1]=='.' 
-          && ss[i+2]=='.' 
-          && ss[i+3]==DIRSEPCHAR){
-        memmove(ss+lastsep+1,ss+i+4,slen-i-3);
-        slen=strlen(ss);
-        i = lastsep;
-        break;
-      } else {
-        if(ss[i]==DIRSEPCHAR) 
-          lastsep=i; 
-      }
+      if(ss[i]==DIRSEPCHAR && ss[i+1]!='.') lastsep=i;  
+      if(ss[i]!=DIRSEPCHAR) continue;
+      if(ss[i+1]!='.')        continue;
+      if(ss[i+2]!='.')        continue;
+      if(ss[i+3]!=DIRSEPCHAR) continue;
+      memmove(ss+lastsep+1,ss+i+4,slen-i-3);
+      slen=strlen(ss);
+      break;
     }
   }
 #ifdef DEBUGFILE
@@ -877,18 +832,14 @@ int dvistandard(char** dst,char* src) {  /* may be src==filename */
   for(i=0;i<slen-3;){
     lastsep=0;
     for(i=0;i<slen-3;i++) {
-      if(    ss[i]==DIRSEPCHAR 
-          && ss[i+1]=='.' 
-          && ss[i+2]=='.' 
-          && ss[i+3]==DIRSEPCHAR){
-        memmove(ss+lastsep+1,ss+i+4,slen-i-3);
-        slen=strlen(ss);
-        i = lastsep;
-        break;
-      } else {
-        if(ss[i]==DIRSEPCHAR) 
-          lastsep=i;
-      }
+      if(ss[i]==DIRSEPCHAR && ss[i+1]!='.') lastsep=i;  
+      if(ss[i]!=DIRSEPCHAR) continue;
+      if(ss[i+1]!='.')        continue;
+      if(ss[i+2]!='.')        continue;
+      if(ss[i+3]!=DIRSEPCHAR) continue;
+      memmove(ss+lastsep+1,ss+i+4,slen-i-3);
+      slen=strlen(ss);
+      break;
     }
   }
 #ifdef DEBUGFILE
@@ -967,7 +918,6 @@ void alloc_bitmapbw(bitmap* bmp) {
   size = ((long)bmp->bmu_wide)* BYTES_PER_BMUNIT * bmp->h + 1; /* bit blitting needs on extra*/
   alloclrumem(&(bmp->bits),MAX(size,1)); 
   memset(bmp->bits,0,size);
-  /* pfverb("*"); */ 
 }
 
 void alloc_bitmapgs(bitmap* bmp) {
@@ -976,7 +926,6 @@ void alloc_bitmapgs(bitmap* bmp) {
   size = ((long) bmp->bmu_wide)*BYTES_PER_BMUNIT * bmp->h +1; /* bit blitting needs on extra*/;
   alloclrumem(&(bmp->bits),MAX(size,1)); 
   memset(bmp->bits,0,size);
-  /*pfverb("*");*/  
 }
 
 void clear_bitmap(bitmap* bmp) {
@@ -1003,6 +952,7 @@ void print_bitmap(bitmap *bmp) {
 	}
         pfprot("sizes: type = %d, w = %d, h = %d, bmu wide = %d)\n",
 	    bmp->type,bmp->w, bmp->h, bmp->bmu_wide);
+
 }
 
 
