@@ -7,14 +7,10 @@
 void pfprot(char*, ...);
 void pfverb(char*, ...);
 void allocmem(void*,long int);
-void reallocmem(void*, long);
 void freemem(void*);
 void alloclrumem(void*,long int);
-void realloclrumem(void*, long);
 void freelrumem(void*);
 void touchlrumem(void* );
-void locklrumem(void* );
-void unlocklrumem(void* );
 char *stralloccpy(char**, char*);
 long scaled(long,long);
 void alloc_bitmapbw(bitmap*);
