@@ -96,16 +96,25 @@ void vgaopen(void) {
 }
 
 
+
 void setpalette(void) {
   int i,gl;
-  /* grey levels for antialising */
+
   for(i=0;i<COLORS_PER_GREY;i++) {
     gl=(i==0) ? 0: 63 * exp(GAMMA*log(i/(float) (COLORS_PER_GREY-1)));
     if(MECK)  vga_setpalette(COLORS_PER_GREY-1-i,gl,gl,gl);
     else      gl_setpalettecolor(COLORS_PER_GREY-1-i,gl,gl,gl);
   }
-  /* other colors for markers, frames etc. */
-  if(!MECK) {
+  if(MECK) {
+    vga_setpalette(8,PALDRED);   
+    vga_setpalette(9,PALDGREEN);   
+    vga_setpalette(10,PALDBLUE);   
+    vga_setpalette(11,0,0,0);   /* not used */
+    vga_setpalette(12,PALLRED);   
+    vga_setpalette(13,PALLGREEN);  
+    vga_setpalette(14,PALLBLUE);   
+    vga_setpalette(15,PALLGREY);  
+  }else{
     gl_setpalettecolor(SETPALTEXTCOL);           
     gl_setpalettecolor(SETPALTEXTBACKCOL);      
     gl_setpalettecolor(SETPALBORDERCOL);   
@@ -118,15 +127,6 @@ void setpalette(void) {
     gl_setpalettecolor(SETPALMARKHCOL);     
     gl_setpalettecolor(SETPALMARKDCOL);     
     gl_setpalettecolor(SETPALFOUNDCOL);     
-  } else {
-    vga_setpalette(8,PALDRED);   
-    vga_setpalette(9,PALDGREEN);   
-    vga_setpalette(10,PALDBLUE);   
-    vga_setpalette(11,0,0,0);   /* not used */
-    vga_setpalette(12,PALLRED);   
-    vga_setpalette(13,PALLGREEN);  
-    vga_setpalette(14,PALLBLUE);   
-    vga_setpalette(15,PALLGREY);  
   }
 }
 
@@ -234,9 +234,9 @@ warning: display: mode -d640x480 not even supported at 16 colors.\n");
   /* these are colors as bytes in the internal buffer */
   if(!MECK){
      COLORS_PER_GREY   =16;      /* should be 2^BITS_PER_GREY */
+    /* use lots of different values, so you may design a rainbow tmview */     
      WHITECOL          =0;
      BLACKCOL          =(COLORS_PER_GREY-1);
- /* use lots of different values, so you may design a rainbow tmview */     
      BORDERCOL         =COLORS_PER_GREY;
      TEXTCOL           =COLORS_PER_GREY+1;
      TEXTBACKCOL       =COLORS_PER_GREY+2;
@@ -255,12 +255,12 @@ warning: display: mode -d640x480 not even supported at 16 colors.\n");
      NUMBER_OF_COLORS  =COLORS_PER_GREY+23; /*number of colors */
 
   }else{
-    /* Now here we are in 16-color mode, and less fexible.              */
+    /* Now here we are in 16-color mode, and less fexible.
     /* set up 8 greylevels, 3 solid colors, 3 transparent and one mixed */
     /* this is hardwired, cause there are no more colors left           */
     /* if you still want to change the colors, change the rgb tripels in*/
     /* the defssvga.h. That is, make PALDRED look yellow or so          */
-     COLORS_PER_GREY   =8;               /* use only 8 of 16 greyscales */
+     COLORS_PER_GREY   =8;         /* use only 8 of 16 greyscales */
 
      WHITECOL          =0;
      BLACKCOL          =7;
@@ -293,16 +293,12 @@ warning: display: mode -d640x480 not even supported at 16 colors.\n");
     gl_getcontext(&physicalscreen);
     gl_disableclipping();
     setpalette();
+#ifdef VGA_GOTOBACK 
     if(enablebackground){
-      pfprot("vgaopen: background running enabled.\n");
+      pfprot("vgaopen: background running will be enabled.\n");
       vga_runinbackground(1); 
-    } else {
-#ifdef LETSTRYBG
-      pfprot("vgaopen: background running not supported.\n");
-#else
-      pfprot("vgaopen: background running disabled.\n");
-#endif
     }
+#endif
   }else{ /* MECK */
     setpalette();
   }
@@ -412,6 +408,7 @@ uchar vgagetchar(int mode) {
   */
   uchar input,next1,next2,next3;
   uchar com=KEYNOP;
+  fd_set dummy;
   if(mode2char>=0){
      com=mode2char;  
      if(mode!=2) mode2char=-1;
@@ -471,8 +468,8 @@ void vgasetmouse(int x, int y) {
 
 
 void vgagetmouse(int *x, int *y, int *left, int* right) {
-#ifdef HASMOUSE
   int button,nmx,nmy;
+#ifdef HASMOUSE
   mouse_update();
   nmx = mouse_getx();
   nmy = mouse_gety();
@@ -496,18 +493,16 @@ void vgagetmouse(int *x, int *y, int *left, int* right) {
 void vgascreen(int son) {  
 }
 
+
+
 /**************************************************************************/
 /*
    now the pixel copy stuff. 
    destination is allways the offscreen context  
 */
 
-int mydimm(int color, int dimm) {
-  return(color>>dimm);
-}
 
-
-void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
+void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -517,7 +512,6 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
   register BMUNIT data, mask;
   short sbmu_wide;
   char *ydest, *xdest;
-  uchar blackc;
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -534,7 +528,6 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
   /* fprintf(prot,"clipped: tx %d ty %d mi %d si %d mj %d sj %d \n",
      tx,ty,mini,supi,minj,supj); */
   
-  blackc=(*vgadimm)(BLACKCOL,c);
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
@@ -553,7 +546,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
         mask=premask;
         data= *(++sbmu);
       }
-      if(data & mask) *xdest=blackc;
+      if(data & mask) *xdest=BLACKCOL;
       mask >>= 1;
       xdest+=PTDELTAH;
     }
@@ -565,7 +558,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
 
 
 
-void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) { 
+void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -573,11 +566,10 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) {
   int j,i,supi,supj,mini,minj,sx, skip;
   BMUNIT *srow, *sbmu;
   BMUNIT premask, firstpremask;
-  BMUNIT data, mask;
+  register BMUNIT data, mask;
   short sbmu_wide;
   int rs, firstrs;
   char *ydest, *xdest;
-  char paintc, sourcec;
 
 #ifdef DEBUGVGA
   pfprot("(mycopybitsgs : ptr 0x%x tx %d ty %d sw %d sh %d, ...",
@@ -622,17 +614,7 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) {
         data= *(++sbmu); 
       }
       /* pfprot("- ptr 0x%x data %d -",xdest,((data &mask)>>rs));  */
-#ifndef LETSTRYCOLOR
-      (*xdest) |= ((data & mask) >> rs); /* sleezy but fast ..(rs+c)*/
-#else
-      if((paintc=(data & mask) >> (rs+c))){
-        if((sourcec=(*xdest) & (COLORS_PER_GREY-1))){
-          if((paintc+=sourcec)>COLORS_PER_GREY-1) paintc=COLORS_PER_GREY-1;
-          (*xdest) &= ~(COLORS_PER_GREY-1);
-	}
-        (*xdest) |=paintc;
-      }
-#endif
+      (*xdest) |= ((data & mask) >> rs); 
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       xdest+=PTDELTAH;
@@ -652,7 +634,7 @@ void mycopybits88(int tx, int ty, int sw, int sh, char* src) {
 /* copy bytes to bytes                         */
 /* compatible to gl_putbox                     */
 
-  int j,i,supi,supj,mini,minj;
+  int j,i,supi,supj,mini,minj,skip;
   char *srow, *sbmu;
   char *ydest, *xdest;
 
@@ -690,39 +672,28 @@ void mycopybits88(int tx, int ty, int sw, int sh, char* src) {
 void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   char *ydest, *xdest;
-  char sourcec, paintc;
   int i;
 
-  /*pfprot("(vgafillboxor : tx %d ty %d sw %d sh %d c %d, ...\n",
-    tx,ty,w,h,c); */                             
+  /* fprintf(prot,"(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
+       tx,ty,sw, sh); */                             
   if(ty<ofscy1) {h-=ofscy1-ty;  ty=ofscy1;} 
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
   if(tx+w>ofscx2+1) w=ofscx2+1-tx;
-  if(w <= 0 || h<= 0 || c==0) {
-     /*fprintf(prot,"clipped all away or white. no drawings)\n"); */
+  if(w <= 0 || h<= 0) {
+     /*fprintf(prot,"clipped all away. no drawings)\n"); */
      return;
   }
   CXW("rector");
   ydest=ptorigin+ty*PTDELTAV+tx*PTDELTAH;
   /* fprintf(prot,"clipped or box: tx %d ty %d w %d h %d   \n",
      tx,ty,w,h); */ 
-  paintc=0;
+
   for (;h>0;h--) {
     xdest=ydest; 
     for (i=w;i>0;i--) {
        CPT(xdest,"rector")                
-#ifndef LETSTRYCOLOR
-       (*xdest)|=c; /* sleezy but fast    */
-#else
-       if((sourcec=(*xdest) & (COLORS_PER_GREY-1))){
-         if((paintc =c+sourcec)>COLORS_PER_GREY-1) paintc=COLORS_PER_GREY-1;
-         (*xdest) &= ~(COLORS_PER_GREY-1);
-         (*xdest) |=paintc;
-       } else {
-         (*xdest) |=c;
-       }
-#endif
+       (*(xdest))|=c;
        xdest+=PTDELTAH;
     }
     ydest+=PTDELTAV;
@@ -758,7 +729,7 @@ void myfillboxbg(int tx, int ty, int w, int h, int c) {
       CPT(xdest,"rectbg")
       xdc=*xdest; 
       if(xdc) {      
-	/*if(xdc>c) *xdest=c;*/                   /* transparent modus */     
+      /*if(xdc>c) *xdest=c;                       /* transparent modus */     
         if(xdc>BACKCOLS && xdc!= c) *xdest=MIXEDCOL;   /* mixing modus */  
       } else *xdest=c;
       xdest+=PTDELTAH;
@@ -773,6 +744,7 @@ void myfillbox(int tx, int ty, int w, int h, int c) {
   char *ydest;
   int i;
   register char *xdest;
+  register char xdc;
   /* fprintf(prot,"(vgafillbox : tx %d ty %d w %d h %d, ...\n",
        tx,ty,w,h); */                              
   if(ty<ofscy1) {h-=ofscy1-ty;  ty=ofscy1;} 
@@ -827,10 +799,11 @@ void vgaupdatestatus(void) {
 
 
 void vgadrawstatus(char chr, int line, int pos) {
+  int i; 
   if(line>=vgastatuslines || line <0) return;
   if(pos>=vgastatuslen || pos <0) return;
   mysetclipof();
-  /* chr=(line&0x0f)*16 + (pos&0x0f); *//* test charset */
+  /* chr=(line&0x0f)*16 + (pos&0x0f);  /* test charset */
   mycopybits88(pos*fontw+1, vgaydim+(line+1)* vgastatushight-fonth, 
         fontw, fonth, expandedfont + (unsigned char) chr *fonth*fontw);
   mysetclip(0,0,vgaxdim-1,vgaydim-1); 
@@ -844,9 +817,8 @@ void (*vgasetclip)(int, int, int, int) = mysetclip;
 void (*vgadrawrect)(int x, int y, int w, int h, int c) = myfillbox; 
 void (*vgadrawrector)(int x, int y, int w, int h, int c) = myfillboxor; 
 void (*vgadrawrectbg)(int x, int y, int w, int h, int c) = myfillboxbg; 
-int  (*vgadimm)(int, int) = mydimm;
-void (*vgacopybitmapgs)(int x,int y,int w,int h,void* src,int c)=mycopybitsgs; 
-void (*vgacopybitmapbw)(int x,int y,int w,int h,void* src,int c)=mycopybitsbw;
+void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src) = mycopybitsgs; 
+void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src) = mycopybitsbw;
 
 
 /***************************************************************************/
@@ -860,6 +832,7 @@ void (*vgacopybitmapbw)(int x,int y,int w,int h,void* src,int c)=mycopybitsbw;
 
 void preparefont(void) {
   long i;
+  char* buptr;
   fonth=FONTH;
   fontw=FONTW;
   fonts=FONTS;
