@@ -5,21 +5,16 @@
 
 void vgaopen(void);
 void vgagraph(void);
-void vgaxscroll(short);
-void vgayscroll(short);
 void vgaclose(void);
 unsigned char vgagetchar(int);
-void vgasetmouse(int, int);
-void vgagetmouse(int*, int*, int*, int*);
 int vgawaitio(fd_set * fdsetin, fd_set * fdsetout, struct timeval *timeout);
 void (*vgasetclip)(int, int, int, int);
 void (*vgaupdate)(int, int, int, int);
 void (*vgadrawrect)(int, int, int, int, int);
 void (*vgadrawrector)(int, int, int, int, int);
 void (*vgadrawrectbg)(int, int, int, int, int);
-void (*vgacopybitmapgs)(int, int, int, int, void*, int);
-void (*vgacopybitmapbw)(int, int, int, int, void*, int);
-int  (*vgadimm)(int, int);
+void (*vgacopybitmapgs)(int, int, int, int, void*);
+void (*vgacopybitmapbw)(int, int, int, int, void*);
 void vgascreen(int);
 void vgadrawstatus(char, int, int);
 void vgaupdatestatus(void);
